@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Recursive Descent Parser Application
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -63,10 +63,9 @@ Keyboard Shortcuts::
       [Ctrl-p]\t Print
       [q]\t Quit
 """
-from __future__ import division
 
-from six.moves.tkinter_font import Font
-from six.moves.tkinter import Listbox, IntVar, Button, Frame, Label, Menu, Scrollbar, Tk
+from tkinter.font import Font
+from tkinter import Listbox, IntVar, Button, Frame, Label, Menu, Scrollbar, Tk
 
 from nltk.tree import Tree
 from nltk.util import in_idle
@@ -92,7 +91,7 @@ class RecursiveDescentApp(object):
 
         # Set up the main window.
         self._top = Tk()
-        self._top.title('Recursive Descent Parser Application')
+        self._top.title("Recursive Descent Parser Application")
 
         # Set up key bindings.
         self._init_bindings()
@@ -122,7 +121,7 @@ class RecursiveDescentApp(object):
         self._parser.initialize(self._sent)
 
         # Resize callback
-        self._canvas.bind('<Configure>', self._configure)
+        self._canvas.bind("<Configure>", self._configure)
 
     #########################################
     ##  Initialization Helpers
@@ -135,127 +134,127 @@ class RecursiveDescentApp(object):
 
         # TWhat's our font size (default=same as sysfont)
         self._size = IntVar(root)
-        self._size.set(self._sysfont.cget('size'))
+        self._size.set(self._sysfont.cget("size"))
 
-        self._boldfont = Font(family='helvetica', weight='bold', size=self._size.get())
-        self._font = Font(family='helvetica', size=self._size.get())
+        self._boldfont = Font(family="helvetica", weight="bold", size=self._size.get())
+        self._font = Font(family="helvetica", size=self._size.get())
         if self._size.get() < 0:
             big = self._size.get() - 2
         else:
             big = self._size.get() + 2
-        self._bigfont = Font(family='helvetica', weight='bold', size=big)
+        self._bigfont = Font(family="helvetica", weight="bold", size=big)
 
     def _init_grammar(self, parent):
         # Grammar view.
         self._prodframe = listframe = Frame(parent)
-        self._prodframe.pack(fill='both', side='left', padx=2)
+        self._prodframe.pack(fill="both", side="left", padx=2)
         self._prodlist_label = Label(
-            self._prodframe, font=self._boldfont, text='Available Expansions'
+            self._prodframe, font=self._boldfont, text="Available Expansions"
         )
         self._prodlist_label.pack()
         self._prodlist = Listbox(
             self._prodframe,
-            selectmode='single',
-            relief='groove',
-            background='white',
-            foreground='#909090',
+            selectmode="single",
+            relief="groove",
+            background="white",
+            foreground="#909090",
             font=self._font,
-            selectforeground='#004040',
-            selectbackground='#c0f0c0',
+            selectforeground="#004040",
+            selectbackground="#c0f0c0",
         )
 
-        self._prodlist.pack(side='right', fill='both', expand=1)
+        self._prodlist.pack(side="right", fill="both", expand=1)
 
         self._productions = list(self._parser.grammar().productions())
         for production in self._productions:
-            self._prodlist.insert('end', ('  %s' % production))
+            self._prodlist.insert("end", ("  %s" % production))
         self._prodlist.config(height=min(len(self._productions), 25))
 
         # Add a scrollbar if there are more than 25 productions.
         if len(self._productions) > 25:
-            listscroll = Scrollbar(self._prodframe, orient='vertical')
+            listscroll = Scrollbar(self._prodframe, orient="vertical")
             self._prodlist.config(yscrollcommand=listscroll.set)
             listscroll.config(command=self._prodlist.yview)
-            listscroll.pack(side='left', fill='y')
+            listscroll.pack(side="left", fill="y")
 
         # If they select a production, apply it.
-        self._prodlist.bind('<<ListboxSelect>>', self._prodlist_select)
+        self._prodlist.bind("<<ListboxSelect>>", self._prodlist_select)
 
     def _init_bindings(self):
         # Key bindings are a good thing.
-        self._top.bind('<Control-q>', self.destroy)
-        self._top.bind('<Control-x>', self.destroy)
-        self._top.bind('<Escape>', self.destroy)
-        self._top.bind('e', self.expand)
+        self._top.bind("<Control-q>", self.destroy)
+        self._top.bind("<Control-x>", self.destroy)
+        self._top.bind("<Escape>", self.destroy)
+        self._top.bind("e", self.expand)
         # self._top.bind('<Alt-e>', self.expand)
         # self._top.bind('<Control-e>', self.expand)
-        self._top.bind('m', self.match)
-        self._top.bind('<Alt-m>', self.match)
-        self._top.bind('<Control-m>', self.match)
-        self._top.bind('b', self.backtrack)
-        self._top.bind('<Alt-b>', self.backtrack)
-        self._top.bind('<Control-b>', self.backtrack)
-        self._top.bind('<Control-z>', self.backtrack)
-        self._top.bind('<BackSpace>', self.backtrack)
-        self._top.bind('a', self.autostep)
+        self._top.bind("m", self.match)
+        self._top.bind("<Alt-m>", self.match)
+        self._top.bind("<Control-m>", self.match)
+        self._top.bind("b", self.backtrack)
+        self._top.bind("<Alt-b>", self.backtrack)
+        self._top.bind("<Control-b>", self.backtrack)
+        self._top.bind("<Control-z>", self.backtrack)
+        self._top.bind("<BackSpace>", self.backtrack)
+        self._top.bind("a", self.autostep)
         # self._top.bind('<Control-a>', self.autostep)
-        self._top.bind('<Control-space>', self.autostep)
-        self._top.bind('<Control-c>', self.cancel_autostep)
-        self._top.bind('<space>', self.step)
-        self._top.bind('<Delete>', self.reset)
-        self._top.bind('<Control-p>', self.postscript)
+        self._top.bind("<Control-space>", self.autostep)
+        self._top.bind("<Control-c>", self.cancel_autostep)
+        self._top.bind("<space>", self.step)
+        self._top.bind("<Delete>", self.reset)
+        self._top.bind("<Control-p>", self.postscript)
         # self._top.bind('<h>', self.help)
         # self._top.bind('<Alt-h>', self.help)
-        self._top.bind('<Control-h>', self.help)
-        self._top.bind('<F1>', self.help)
+        self._top.bind("<Control-h>", self.help)
+        self._top.bind("<F1>", self.help)
         # self._top.bind('<g>', self.toggle_grammar)
         # self._top.bind('<Alt-g>', self.toggle_grammar)
         # self._top.bind('<Control-g>', self.toggle_grammar)
-        self._top.bind('<Control-g>', self.edit_grammar)
-        self._top.bind('<Control-t>', self.edit_sentence)
+        self._top.bind("<Control-g>", self.edit_grammar)
+        self._top.bind("<Control-t>", self.edit_sentence)
 
     def _init_buttons(self, parent):
         # Set up the frames.
         self._buttonframe = buttonframe = Frame(parent)
-        buttonframe.pack(fill='none', side='bottom', padx=3, pady=2)
+        buttonframe.pack(fill="none", side="bottom", padx=3, pady=2)
         Button(
             buttonframe,
-            text='Step',
-            background='#90c0d0',
-            foreground='black',
+            text="Step",
+            background="#90c0d0",
+            foreground="black",
             command=self.step,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Autostep',
-            background='#90c0d0',
-            foreground='black',
+            text="Autostep",
+            background="#90c0d0",
+            foreground="black",
             command=self.autostep,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Expand',
+            text="Expand",
             underline=0,
-            background='#90f090',
-            foreground='black',
+            background="#90f090",
+            foreground="black",
             command=self.expand,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Match',
+            text="Match",
             underline=0,
-            background='#90f090',
-            foreground='black',
+            background="#90f090",
+            foreground="black",
             command=self.match,
-        ).pack(side='left')
+        ).pack(side="left")
         Button(
             buttonframe,
-            text='Backtrack',
+            text="Backtrack",
             underline=0,
-            background='#f0a0a0',
-            foreground='black',
+            background="#f0a0a0",
+            foreground="black",
             command=self.backtrack,
-        ).pack(side='left')
+        ).pack(side="left")
         # Replace autostep...
 
     #         self._autostep_button = Button(buttonframe, text='Autostep',
@@ -266,42 +265,42 @@ class RecursiveDescentApp(object):
         self._autostep = 0
         (x1, y1, x2, y2) = self._cframe.scrollregion()
         y2 = event.height - 6
-        self._canvas['scrollregion'] = '%d %d %d %d' % (x1, y1, x2, y2)
+        self._canvas["scrollregion"] = "%d %d %d %d" % (x1, y1, x2, y2)
         self._redraw()
 
     def _init_feedback(self, parent):
         self._feedbackframe = feedbackframe = Frame(parent)
-        feedbackframe.pack(fill='x', side='bottom', padx=3, pady=3)
+        feedbackframe.pack(fill="x", side="bottom", padx=3, pady=3)
         self._lastoper_label = Label(
-            feedbackframe, text='Last Operation:', font=self._font
+            feedbackframe, text="Last Operation:", font=self._font
         )
-        self._lastoper_label.pack(side='left')
-        lastoperframe = Frame(feedbackframe, relief='sunken', border=1)
-        lastoperframe.pack(fill='x', side='right', expand=1, padx=5)
+        self._lastoper_label.pack(side="left")
+        lastoperframe = Frame(feedbackframe, relief="sunken", border=1)
+        lastoperframe.pack(fill="x", side="right", expand=1, padx=5)
         self._lastoper1 = Label(
-            lastoperframe, foreground='#007070', background='#f0f0f0', font=self._font
+            lastoperframe, foreground="#007070", background="#f0f0f0", font=self._font
         )
         self._lastoper2 = Label(
             lastoperframe,
-            anchor='w',
+            anchor="w",
             width=30,
-            foreground='#004040',
-            background='#f0f0f0',
+            foreground="#004040",
+            background="#f0f0f0",
             font=self._font,
         )
-        self._lastoper1.pack(side='left')
-        self._lastoper2.pack(side='left', fill='x', expand=1)
+        self._lastoper1.pack(side="left")
+        self._lastoper2.pack(side="left", fill="x", expand=1)
 
     def _init_canvas(self, parent):
         self._cframe = CanvasFrame(
             parent,
-            background='white',
+            background="white",
             # width=525, height=250,
             closeenough=10,
             border=2,
-            relief='sunken',
+            relief="sunken",
         )
-        self._cframe.pack(expand=1, fill='both', side='top', pady=2)
+        self._cframe.pack(expand=1, fill="both", side="top", pady=2)
         canvas = self._canvas = self._cframe.canvas()
 
         # Initially, there's no tree or text
@@ -314,50 +313,50 @@ class RecursiveDescentApp(object):
 
         filemenu = Menu(menubar, tearoff=0)
         filemenu.add_command(
-            label='Reset Parser', underline=0, command=self.reset, accelerator='Del'
+            label="Reset Parser", underline=0, command=self.reset, accelerator="Del"
         )
         filemenu.add_command(
-            label='Print to Postscript',
+            label="Print to Postscript",
             underline=0,
             command=self.postscript,
-            accelerator='Ctrl-p',
+            accelerator="Ctrl-p",
         )
         filemenu.add_command(
-            label='Exit', underline=1, command=self.destroy, accelerator='Ctrl-x'
+            label="Exit", underline=1, command=self.destroy, accelerator="Ctrl-x"
         )
-        menubar.add_cascade(label='File', underline=0, menu=filemenu)
+        menubar.add_cascade(label="File", underline=0, menu=filemenu)
 
         editmenu = Menu(menubar, tearoff=0)
         editmenu.add_command(
-            label='Edit Grammar',
+            label="Edit Grammar",
             underline=5,
             command=self.edit_grammar,
-            accelerator='Ctrl-g',
+            accelerator="Ctrl-g",
         )
         editmenu.add_command(
-            label='Edit Text',
+            label="Edit Text",
             underline=5,
             command=self.edit_sentence,
-            accelerator='Ctrl-t',
+            accelerator="Ctrl-t",
         )
-        menubar.add_cascade(label='Edit', underline=0, menu=editmenu)
+        menubar.add_cascade(label="Edit", underline=0, menu=editmenu)
 
         rulemenu = Menu(menubar, tearoff=0)
         rulemenu.add_command(
-            label='Step', underline=1, command=self.step, accelerator='Space'
+            label="Step", underline=1, command=self.step, accelerator="Space"
         )
         rulemenu.add_separator()
         rulemenu.add_command(
-            label='Match', underline=0, command=self.match, accelerator='Ctrl-m'
+            label="Match", underline=0, command=self.match, accelerator="Ctrl-m"
         )
         rulemenu.add_command(
-            label='Expand', underline=0, command=self.expand, accelerator='Ctrl-e'
+            label="Expand", underline=0, command=self.expand, accelerator="Ctrl-e"
         )
         rulemenu.add_separator()
         rulemenu.add_command(
-            label='Backtrack', underline=0, command=self.backtrack, accelerator='Ctrl-b'
+            label="Backtrack", underline=0, command=self.backtrack, accelerator="Ctrl-b"
         )
-        menubar.add_cascade(label='Apply', underline=0, menu=rulemenu)
+        menubar.add_cascade(label="Apply", underline=0, menu=rulemenu)
 
         viewmenu = Menu(menubar, tearoff=0)
         viewmenu.add_checkbutton(
@@ -368,41 +367,41 @@ class RecursiveDescentApp(object):
         )
         viewmenu.add_separator()
         viewmenu.add_radiobutton(
-            label='Tiny',
+            label="Tiny",
             variable=self._size,
             underline=0,
             value=10,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Small',
+            label="Small",
             variable=self._size,
             underline=0,
             value=12,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Medium',
+            label="Medium",
             variable=self._size,
             underline=0,
             value=14,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Large',
+            label="Large",
             variable=self._size,
             underline=0,
             value=18,
             command=self.resize,
         )
         viewmenu.add_radiobutton(
-            label='Huge',
+            label="Huge",
             variable=self._size,
             underline=0,
             value=24,
             command=self.resize,
         )
-        menubar.add_cascade(label='View', underline=0, menu=viewmenu)
+        menubar.add_cascade(label="View", underline=0, menu=viewmenu)
 
         animatemenu = Menu(menubar, tearoff=0)
         animatemenu.add_radiobutton(
@@ -413,30 +412,30 @@ class RecursiveDescentApp(object):
             underline=0,
             variable=self._animation_frames,
             value=10,
-            accelerator='-',
+            accelerator="-",
         )
         animatemenu.add_radiobutton(
             label="Normal Animation",
             underline=0,
             variable=self._animation_frames,
             value=5,
-            accelerator='=',
+            accelerator="=",
         )
         animatemenu.add_radiobutton(
             label="Fast Animation",
             underline=0,
             variable=self._animation_frames,
             value=2,
-            accelerator='+',
+            accelerator="+",
         )
         menubar.add_cascade(label="Animate", underline=1, menu=animatemenu)
 
         helpmenu = Menu(menubar, tearoff=0)
-        helpmenu.add_command(label='About', underline=0, command=self.about)
+        helpmenu.add_command(label="About", underline=0, command=self.about)
         helpmenu.add_command(
-            label='Instructions', underline=0, command=self.help, accelerator='F1'
+            label="Instructions", underline=0, command=self.help, accelerator="F1"
         )
-        menubar.add_cascade(label='Help', underline=0, menu=helpmenu)
+        menubar.add_cascade(label="Help", underline=0, menu=helpmenu)
 
         parent.config(menu=menubar)
 
@@ -467,20 +466,20 @@ class RecursiveDescentApp(object):
             self._canvas.delete(self._textline)
 
         # Draw the tree.
-        helv = ('helvetica', -self._size.get())
-        bold = ('helvetica', -self._size.get(), 'bold')
+        helv = ("helvetica", -self._size.get())
+        bold = ("helvetica", -self._size.get(), "bold")
         attribs = {
-            'tree_color': '#000000',
-            'tree_width': 2,
-            'node_font': bold,
-            'leaf_font': helv,
+            "tree_color": "#000000",
+            "tree_width": 2,
+            "node_font": bold,
+            "leaf_font": helv,
         }
         tree = self._parser.tree()
         self._tree = tree_to_treesegment(canvas, tree, **attribs)
         self._cframe.add_widget(self._tree, 30, 5)
 
         # Draw the text.
-        helv = ('helvetica', -self._size.get())
+        helv = ("helvetica", -self._size.get())
         bottom = y = self._cframe.scrollregion()[3]
         self._textwidgets = [
             TextWidget(canvas, word, font=self._font) for word in self._sent
@@ -491,7 +490,7 @@ class RecursiveDescentApp(object):
             y = min(y, twidget.bbox()[1])
 
         # Draw a line over the text, to separate it from the tree.
-        self._textline = canvas.create_line(-5000, y - 5, 5000, y - 5, dash='.')
+        self._textline = canvas.create_line(-5000, y - 5, 5000, y - 5, dash=".")
 
         # Highlight appropriate nodes.
         self._highlight_nodes()
@@ -508,30 +507,30 @@ class RecursiveDescentApp(object):
 
     def _highlight_nodes(self):
         # Highlight the list of nodes to be checked.
-        bold = ('helvetica', -self._size.get(), 'bold')
+        bold = ("helvetica", -self._size.get(), "bold")
         for treeloc in self._parser.frontier()[:1]:
-            self._get(self._tree, treeloc)['color'] = '#20a050'
-            self._get(self._tree, treeloc)['font'] = bold
+            self._get(self._tree, treeloc)["color"] = "#20a050"
+            self._get(self._tree, treeloc)["font"] = bold
         for treeloc in self._parser.frontier()[1:]:
-            self._get(self._tree, treeloc)['color'] = '#008080'
+            self._get(self._tree, treeloc)["color"] = "#008080"
 
     def _highlight_prodlist(self):
         # Highlight the productions that can be expanded.
         # Boy, too bad tkinter doesn't implement Listbox.itemconfig;
         # that would be pretty useful here.
-        self._prodlist.delete(0, 'end')
+        self._prodlist.delete(0, "end")
         expandable = self._parser.expandable_productions()
         untried = self._parser.untried_expandable_productions()
         productions = self._productions
         for index in range(len(productions)):
             if productions[index] in expandable:
                 if productions[index] in untried:
-                    self._prodlist.insert(index, ' %s' % productions[index])
+                    self._prodlist.insert(index, " %s" % productions[index])
                 else:
-                    self._prodlist.insert(index, ' %s (TRIED)' % productions[index])
+                    self._prodlist.insert(index, " %s (TRIED)" % productions[index])
                 self._prodlist.selection_set(index)
             else:
-                self._prodlist.insert(index, ' %s' % productions[index])
+                self._prodlist.insert(index, " %s" % productions[index])
 
     def _position_text(self):
         # Line up the text widgets that are matched against the tree
@@ -542,22 +541,22 @@ class RecursiveDescentApp(object):
         for i in range(0, len(leaves)):
             widget = self._textwidgets[i]
             leaf = leaves[i]
-            widget['color'] = '#006040'
-            leaf['color'] = '#006040'
+            widget["color"] = "#006040"
+            leaf["color"] = "#006040"
             widget.move(leaf.bbox()[0] - widget.bbox()[0], 0)
             xmax = widget.bbox()[2] + 10
 
         # Line up the text widgets that are not matched against the tree.
         for i in range(len(leaves), numwords):
             widget = self._textwidgets[i]
-            widget['color'] = '#a0a0a0'
+            widget["color"] = "#a0a0a0"
             widget.move(xmax - widget.bbox()[0], 0)
             xmax = widget.bbox()[2] + 10
 
         # If we have a complete parse, make everything green :)
         if self._parser.currently_complete():
             for twidget in self._textwidgets:
-                twidget['color'] = '#00a000'
+                twidget["color"] = "#00a000"
 
         # Move the matched leaves down to the text.
         for i in range(0, len(leaves)):
@@ -592,8 +591,8 @@ class RecursiveDescentApp(object):
     def reset(self, *e):
         self._autostep = 0
         self._parser.initialize(self._sent)
-        self._lastoper1['text'] = 'Reset Application'
-        self._lastoper2['text'] = ''
+        self._lastoper1["text"] = "Reset Application"
+        self._lastoper2["text"] = ""
         self._redraw()
 
     def autostep(self, *e):
@@ -638,14 +637,14 @@ class RecursiveDescentApp(object):
         elif self._backtrack():
             pass
         else:
-            self._lastoper1['text'] = 'Finished'
-            self._lastoper2['text'] = ''
+            self._lastoper1["text"] = "Finished"
+            self._lastoper2["text"] = ""
             self._autostep = 0
 
         # Check if we just completed a parse.
         if self._parser.currently_complete():
             self._autostep = 0
-            self._lastoper2['text'] += '    [COMPLETE PARSE]'
+            self._lastoper2["text"] += "    [COMPLETE PARSE]"
 
     def _expand(self, *e):
         if self._animating_lock:
@@ -653,16 +652,16 @@ class RecursiveDescentApp(object):
         old_frontier = self._parser.frontier()
         rv = self._parser.expand()
         if rv is not None:
-            self._lastoper1['text'] = 'Expand:'
-            self._lastoper2['text'] = rv
-            self._prodlist.selection_clear(0, 'end')
+            self._lastoper1["text"] = "Expand:"
+            self._lastoper2["text"] = rv
+            self._prodlist.selection_clear(0, "end")
             index = self._productions.index(rv)
             self._prodlist.selection_set(index)
             self._animate_expand(old_frontier[0])
             return True
         else:
-            self._lastoper1['text'] = 'Expand:'
-            self._lastoper2['text'] = '(all expansions tried)'
+            self._lastoper1["text"] = "Expand:"
+            self._lastoper2["text"] = "(all expansions tried)"
             return False
 
     def _match(self, *e):
@@ -671,13 +670,13 @@ class RecursiveDescentApp(object):
         old_frontier = self._parser.frontier()
         rv = self._parser.match()
         if rv is not None:
-            self._lastoper1['text'] = 'Match:'
-            self._lastoper2['text'] = rv
+            self._lastoper1["text"] = "Match:"
+            self._lastoper2["text"] = rv
             self._animate_match(old_frontier[0])
             return True
         else:
-            self._lastoper1['text'] = 'Match:'
-            self._lastoper2['text'] = '(failed)'
+            self._lastoper1["text"] = "Match:"
+            self._lastoper2["text"] = "(failed)"
             return False
 
     def _backtrack(self, *e):
@@ -687,8 +686,8 @@ class RecursiveDescentApp(object):
             elt = self._parser.tree()
             for i in self._parser.frontier()[0]:
                 elt = elt[i]
-            self._lastoper1['text'] = 'Backtrack'
-            self._lastoper2['text'] = ''
+            self._lastoper1["text"] = "Backtrack"
+            self._lastoper2["text"] = ""
             if isinstance(elt, Tree):
                 self._animate_backtrack(self._parser.frontier()[0])
             else:
@@ -696,17 +695,17 @@ class RecursiveDescentApp(object):
             return True
         else:
             self._autostep = 0
-            self._lastoper1['text'] = 'Finished'
-            self._lastoper2['text'] = ''
+            self._lastoper1["text"] = "Finished"
+            self._lastoper2["text"] = ""
             return False
 
     def about(self, *e):
         ABOUT = (
             "NLTK Recursive Descent Parser Application\n" + "Written by Edward Loper"
         )
-        TITLE = 'About: Recursive Descent Parser Application'
+        TITLE = "About: Recursive Descent Parser Application"
         try:
-            from six.moves.tkinter_messagebox import Message
+            from tkinter.messagebox import Message
 
             Message(message=ABOUT, title=TITLE).show()
         except:
@@ -718,16 +717,16 @@ class RecursiveDescentApp(object):
         try:
             ShowText(
                 self._top,
-                'Help: Recursive Descent Parser Application',
-                (__doc__ or '').strip(),
+                "Help: Recursive Descent Parser Application",
+                (__doc__ or "").strip(),
                 width=75,
-                font='fixed',
+                font="fixed",
             )
         except:
             ShowText(
                 self._top,
-                'Help: Recursive Descent Parser Application',
-                (__doc__ or '').strip(),
+                "Help: Recursive Descent Parser Application",
+                (__doc__ or "").strip(),
                 width=75,
             )
 
@@ -763,13 +762,13 @@ class RecursiveDescentApp(object):
     def _toggle_grammar(self, *e):
         if self._show_grammar.get():
             self._prodframe.pack(
-                fill='both', side='left', padx=2, after=self._feedbackframe
+                fill="both", side="left", padx=2, after=self._feedbackframe
             )
-            self._lastoper1['text'] = 'Show Grammar'
+            self._lastoper1["text"] = "Show Grammar"
         else:
             self._prodframe.pack_forget()
-            self._lastoper1['text'] = 'Hide Grammar'
-        self._lastoper2['text'] = ''
+            self._lastoper1["text"] = "Hide Grammar"
+        self._lastoper2["text"] = ""
 
     #     def toggle_grammar(self, *e):
     #         self._show_grammar = not self._show_grammar
@@ -791,14 +790,14 @@ class RecursiveDescentApp(object):
         production = self._parser.expand(self._productions[index])
 
         if production:
-            self._lastoper1['text'] = 'Expand:'
-            self._lastoper2['text'] = production
-            self._prodlist.selection_clear(0, 'end')
+            self._lastoper1["text"] = "Expand:"
+            self._lastoper2["text"] = production
+            self._prodlist.selection_clear(0, "end")
             self._prodlist.selection_set(index)
             self._animate_expand(old_frontier[0])
         else:
             # Reset the production selections.
-            self._prodlist.selection_clear(0, 'end')
+            self._prodlist.selection_clear(0, "end")
             for prod in self._parser.expandable_productions():
                 index = self._productions.index(prod)
                 self._prodlist.selection_set(index)
@@ -820,13 +819,13 @@ class RecursiveDescentApp(object):
             self._canvas,
             tree,
             node_font=self._boldfont,
-            leaf_color='white',
+            leaf_color="white",
             tree_width=2,
-            tree_color='white',
-            node_color='white',
+            tree_color="white",
+            node_color="white",
             leaf_font=self._font,
         )
-        widget.label()['color'] = '#20a050'
+        widget.label()["color"] = "#20a050"
 
         (oldx, oldy) = oldtree.label().bbox()[:2]
         (newx, newy) = widget.label().bbox()[:2]
@@ -859,7 +858,7 @@ class RecursiveDescentApp(object):
             oldtree.destroy()
 
         colors = [
-            'gray%d' % (10 * int(10 * x / self._animation_frames.get()))
+            "gray%d" % (10 * int(10 * x / self._animation_frames.get()))
             for x in range(self._animation_frames.get(), 0, -1)
         ]
 
@@ -901,22 +900,22 @@ class RecursiveDescentApp(object):
     def _animate_expand_frame(self, widget, colors):
         if len(colors) > 0:
             self._animating_lock = 1
-            widget['color'] = colors[0]
+            widget["color"] = colors[0]
             for subtree in widget.subtrees():
                 if isinstance(subtree, TreeSegmentWidget):
-                    subtree.label()['color'] = colors[0]
+                    subtree.label()["color"] = colors[0]
                 else:
-                    subtree['color'] = colors[0]
+                    subtree["color"] = colors[0]
             self._top.after(50, self._animate_expand_frame, widget, colors[1:])
         else:
-            widget['color'] = 'black'
+            widget["color"] = "black"
             for subtree in widget.subtrees():
                 if isinstance(subtree, TreeSegmentWidget):
-                    subtree.label()['color'] = 'black'
+                    subtree.label()["color"] = "black"
                 else:
-                    subtree['color'] = 'black'
+                    subtree["color"] = "black"
             self._redraw_quick()
-            widget.label()['color'] = 'black'
+            widget.label()["color"] = "black"
             self._animating_lock = 0
             if self._autostep:
                 self._step()
@@ -926,9 +925,9 @@ class RecursiveDescentApp(object):
         if self._animation_frames.get() == 0:
             colors = []
         else:
-            colors = ['#a00000', '#000000', '#a00000']
+            colors = ["#a00000", "#000000", "#a00000"]
         colors += [
-            'gray%d' % (10 * int(10 * x / (self._animation_frames.get())))
+            "gray%d" % (10 * int(10 * x / (self._animation_frames.get())))
             for x in range(1, self._animation_frames.get() + 1)
         ]
 
@@ -945,7 +944,7 @@ class RecursiveDescentApp(object):
         if len(colors) > 0:
             self._animating_lock = 1
             for widget in widgets:
-                widget['color'] = colors[0]
+                widget["color"] = colors[0]
             self._top.after(50, self._animate_backtrack_frame, widgets, colors[1:])
         else:
             for widget in widgets[0].subtrees():
@@ -978,7 +977,7 @@ class RecursiveDescentApp(object):
             widget.move(0, dy)
             self._top.after(10, self._animate_match_frame, frame - 1, widget, dy)
         else:
-            widget['color'] = '#006040'
+            widget["color"] = "#006040"
             self._redraw_quick()
             self._animating_lock = 0
             if self._autostep:
@@ -1004,14 +1003,14 @@ class RecursiveDescentApp(object):
     def set_grammar(self, grammar):
         self._parser.set_grammar(grammar)
         self._productions = list(grammar.productions())
-        self._prodlist.delete(0, 'end')
+        self._prodlist.delete(0, "end")
         for production in self._productions:
-            self._prodlist.insert('end', (' %s' % production))
+            self._prodlist.insert("end", (" %s" % production))
 
     def edit_sentence(self, *e):
         sentence = " ".join(self._sent)
-        title = 'Edit Text'
-        instr = 'Enter a new sentence to parse.'
+        title = "Edit Text"
+        instr = "Enter a new sentence to parse."
         EntryDialog(self._top, sentence, instr, self.set_sentence, title)
 
     def set_sentence(self, sentence):
@@ -1042,12 +1041,12 @@ def app():
     """
     )
 
-    sent = 'the dog saw a man in the park'.split()
+    sent = "the dog saw a man in the park".split()
 
     RecursiveDescentApp(grammar, sent).mainloop()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app()
 
-__all__ = ['app']
+__all__ = ["app"]
