@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Zen Chatbot
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Amy Holland <amyrh@csse.unimelb.edu.au>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -35,7 +35,6 @@ responses are very limited. Zen Chatbot will usually answer very vaguely, or
 respond to a question by asking a different question, in much the same way
 as Eliza.
 """
-from __future__ import print_function
 
 from nltk.chat.util import Chat, reflections
 
@@ -47,7 +46,7 @@ responses = (
     # "good day" etc, but also "good grief!"  and other sentences starting
     # with the word 'good' that may not be a greeting
     (
-        r'(hello(.*))|(good [a-zA-Z]+)',
+        r"(hello(.*))|(good [a-zA-Z]+)",
         (
             "The path to enlightenment is often difficult to see.",
             "Greetings. I sense your mind is troubled. Tell me of your troubles.",
@@ -65,7 +64,7 @@ responses = (
     # interpretation only makes sense for some inputs
     #
     (
-        r'i need (.*)',
+        r"i need (.*)",
         (
             "%1 can be achieved by hard work and dedication of the mind.",
             "%1 is not a need, but a desire of the mind. Clear your mind of such concerns.",
@@ -73,7 +72,7 @@ responses = (
         ),
     ),
     (
-        r'i want (.*)',
+        r"i want (.*)",
         (
             "Desires of the heart will distract you from the path to enlightenment.",
             "Will%1 help you attain enlightenment?",
@@ -89,27 +88,27 @@ responses = (
     #     chatbot: "Are you sure I tell you?"
     # - this style works for positives (e.g. "why do you like cake?")
     #   but does not work for negatives (e.g. "why don't you like cake?")
-    (r'why (.*) i (.*)\?', ("You%1%2?", "Perhaps you only think you%1%2")),
-    (r'why (.*) you(.*)\?', ("Why%1 you%2?", "%2 I%1", "Are you sure I%2?")),
-    (r'why (.*)\?', ("I cannot tell you why%1.", "Why do you think %1?")),
+    (r"why (.*) i (.*)\?", ("You%1%2?", "Perhaps you only think you%1%2")),
+    (r"why (.*) you(.*)\?", ("Why%1 you%2?", "%2 I%1", "Are you sure I%2?")),
+    (r"why (.*)\?", ("I cannot tell you why%1.", "Why do you think %1?")),
     # e.g. "are you listening?", "are you a duck"
     (
-        r'are you (.*)\?',
+        r"are you (.*)\?",
         ("Maybe%1, maybe not%1.", "Whether I am%1 or not is God's business."),
     ),
     # e.g. "am I a duck?", "am I going to die?"
     (
-        r'am i (.*)\?',
+        r"am i (.*)\?",
         ("Perhaps%1, perhaps not%1.", "Whether you are%1 or not is not for me to say."),
     ),
     # what questions, e.g. "what time is it?"
     # problems:
     #     person:  "What do you want?"
     #    chatbot: "Seek truth, not what do me want."
-    (r'what (.*)\?', ("Seek truth, not what%1.", "What%1 should not concern you.")),
+    (r"what (.*)\?", ("Seek truth, not what%1.", "What%1 should not concern you.")),
     # how questions, e.g. "how do you do?"
     (
-        r'how (.*)\?',
+        r"how (.*)\?",
         (
             "How do you suppose?",
             "Will an answer to that really help in your search for enlightenment?",
@@ -118,7 +117,7 @@ responses = (
     ),
     # can questions, e.g. "can you run?", "can you come over here please?"
     (
-        r'can you (.*)\?',
+        r"can you (.*)\?",
         (
             "I probably can, but I may not.",
             "Maybe I can%1, and maybe I cannot.",
@@ -127,7 +126,7 @@ responses = (
     ),
     # can questions, e.g. "can I have some cake?", "can I know truth?"
     (
-        r'can i (.*)\?',
+        r"can i (.*)\?",
         (
             "You can%1 if you believe you can%1, and have a pure spirit.",
             "Seek truth and you will know if you can%1.",
@@ -135,7 +134,7 @@ responses = (
     ),
     # e.g. "It is raining" - implies the speaker is certain of a fact
     (
-        r'it is (.*)',
+        r"it is (.*)",
         (
             "How can you be certain that%1, when you do not even know yourself?",
             "Whether it is%1 or not does not change the way the world is.",
@@ -143,14 +142,14 @@ responses = (
     ),
     # e.g. "is there a doctor in the house?"
     (
-        r'is there (.*)\?',
+        r"is there (.*)\?",
         ("There is%1 if you believe there is.", "It is possible that there is%1."),
     ),
     # e.g. "is it possible?", "is this true?"
-    (r'is(.*)\?', ("%1 is not relevant.", "Does this matter?")),
+    (r"is(.*)\?", ("%1 is not relevant.", "Does this matter?")),
     # non-specific question
     (
-        r'(.*)\?',
+        r"(.*)\?",
         (
             "Do you think %1?",
             "You seek the truth. Does the truth seek you?",
@@ -160,7 +159,7 @@ responses = (
     ),
     # expression of hate of form "I hate you" or "Kelly hates cheese"
     (
-        r'(.*) (hate[s]?)|(dislike[s]?)|(don\'t like)(.*)',
+        r"(.*) (hate[s]?)|(dislike[s]?)|(don\'t like)(.*)",
         (
             "Perhaps it is not about hating %2, but about hate from within.",
             "Weeds only grow when we dislike them",
@@ -169,7 +168,7 @@ responses = (
     ),
     # statement containing the word 'truth'
     (
-        r'(.*) truth(.*)',
+        r"(.*) truth(.*)",
         (
             "Seek truth, and truth will seek you.",
             "Remember, it is not the spoon which bends - only yourself.",
@@ -179,13 +178,13 @@ responses = (
     # desire to do an action
     # e.g. "I want to go shopping"
     (
-        r'i want to (.*)',
+        r"i want to (.*)",
         ("You may %1 if your heart truly desires to.", "You may have to %1."),
     ),
     # desire for an object
     # e.g. "I want a pony"
     (
-        r'i want (.*)',
+        r"i want (.*)",
         (
             "Does your heart truly desire %1?",
             "Is this a desire of the heart, or of the mind?",
@@ -193,7 +192,7 @@ responses = (
     ),
     # e.g. "I can't wait" or "I can't do this"
     (
-        r'i can\'t (.*)',
+        r"i can\'t (.*)",
         (
             "What we can and can't do is a limitation of the mind.",
             "There are limitations of the body, and limitations of the mind.",
@@ -204,7 +203,7 @@ responses = (
     # problem: exceptions...
     # e.g. "I think, therefore I am"
     (
-        r'i think (.*)',
+        r"i think (.*)",
         (
             "Uncertainty in an uncertain world.",
             "Indeed, how can we be certain of anything in such uncertain times.",
@@ -213,7 +212,7 @@ responses = (
     ),
     # "I feel...emotions/sick/light-headed..."
     (
-        r'i feel (.*)',
+        r"i feel (.*)",
         (
             "Your body and your emotions are both symptoms of your mind."
             "What do you believe is the root of such feelings?",
@@ -223,7 +222,7 @@ responses = (
     # exclaimation mark indicating emotion
     # e.g. "Wow!" or "No!"
     (
-        r'(.*)!',
+        r"(.*)!",
         (
             "I sense that you are feeling emotional today.",
             "You need to calm your emotions.",
@@ -232,7 +231,7 @@ responses = (
     # because [statement]
     # e.g. "because I said so"
     (
-        r'because (.*)',
+        r"because (.*)",
         (
             "Does knowning the reasons behind things help you to understand"
             " the things themselves?",
@@ -241,7 +240,7 @@ responses = (
     ),
     # yes or no - raise an issue of certainty/correctness
     (
-        r'(yes)|(no)',
+        r"(yes)|(no)",
         (
             "Is there certainty in an uncertain world?",
             "It is better to be right than to be certain.",
@@ -249,7 +248,7 @@ responses = (
     ),
     # sentence containing word 'love'
     (
-        r'(.*)love(.*)',
+        r"(.*)love(.*)",
         (
             "Think of the trees: they let the birds perch and fly with no intention to call them when they come, and no longing for their return when they fly away. Let your heart be like the trees.",
             "Free love!",
@@ -257,7 +256,7 @@ responses = (
     ),
     # sentence containing word 'understand' - r
     (
-        r'(.*)understand(.*)',
+        r"(.*)understand(.*)",
         (
             "If you understand, things are just as they are;"
             " if you do not understand, things are just as they are.",
@@ -267,7 +266,7 @@ responses = (
     # 'I', 'me', 'my' - person is talking about themself.
     # this breaks down when words contain these - eg 'Thyme', 'Irish'
     (
-        r'(.*)(me )|( me)|(my)|(mine)|(i)(.*)',
+        r"(.*)(me )|( me)|(my)|(mine)|(i)(.*)",
         (
             "'I', 'me', 'my'... these are selfish expressions.",
             "Have you ever considered that you might be a selfish person?",
@@ -278,12 +277,12 @@ responses = (
     # 'you' starting a sentence
     # e.g. "you stink!"
     (
-        r'you (.*)',
+        r"you (.*)",
         ("My path is not of conern to you.", "I am but one, and you but one more."),
     ),
     # say goodbye with some extra Zen wisdom.
     (
-        r'exit',
+        r"exit",
         (
             "Farewell. The obstacle is the path.",
             "Farewell. Life is a journey, not a destination.",
@@ -295,7 +294,7 @@ responses = (
     # when stumped, respond with generic zen wisdom
     #
     (
-        r'(.*)',
+        r"(.*)",
         (
             "When you're enlightened, every word is wisdom.",
             "Random talk is useless.",
@@ -310,13 +309,13 @@ zen_chatbot = Chat(responses, reflections)
 
 
 def zen_chat():
-    print('*' * 75)
+    print("*" * 75)
     print("Zen Chatbot!".center(75))
-    print('*' * 75)
+    print("*" * 75)
     print('"Look beyond mere words and letters - look into your mind"'.center(75))
     print("* Talk your way to truth with Zen Chatbot.")
     print("* Type 'quit' when you have had enough.")
-    print('*' * 75)
+    print("*" * 75)
     print("Welcome, my child.")
 
     zen_chatbot.converse()
