@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Twitter Corpus Reader
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -13,8 +13,6 @@ have been serialised into line-delimited JSON.
 import json
 import os
 
-from six import string_types
-
 from nltk.tokenize import TweetTokenizer
 
 from nltk.corpus.reader.util import StreamBackedCorpusView, concat, ZipFilePathPointer
@@ -58,9 +56,9 @@ class TwitterCorpusReader(CorpusReader):
     The corpus view class used by this reader.
     """
 
-    def __init__(self, root, fileids=None,
-                 word_tokenizer=TweetTokenizer(),
-                 encoding='utf8'):
+    def __init__(
+        self, root, fileids=None, word_tokenizer=TweetTokenizer(), encoding="utf8"
+    ):
         """
 
         :param root: The root directory for this corpus.
@@ -82,8 +80,6 @@ class TwitterCorpusReader(CorpusReader):
 
         self._word_tokenizer = word_tokenizer
 
-
-
     def docs(self, fileids=None):
         """
         Returns the full Tweet objects, as specified by `Twitter
@@ -94,9 +90,12 @@ class TwitterCorpusReader(CorpusReader):
         from JSON.
         :rtype: list(dict)
         """
-        return concat([self.CorpusView(path, self._read_tweets, encoding=enc)
-                       for (path, enc, fileid) in self.abspaths(fileids, True, True)])
-
+        return concat(
+            [
+                self.CorpusView(path, self._read_tweets, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def strings(self, fileids=None):
         """
@@ -109,7 +108,7 @@ class TwitterCorpusReader(CorpusReader):
         tweets = []
         for jsono in fulltweets:
             try:
-                text = jsono['text']
+                text = jsono["text"]
                 if isinstance(text, bytes):
                     text = text.decode(self.encoding)
                 tweets.append(text)
@@ -117,7 +116,6 @@ class TwitterCorpusReader(CorpusReader):
                 pass
         return tweets
 
-
     def tokenized(self, fileids=None):
         """
         :return: the given file(s) as a list of the text content of Tweets as
@@ -129,18 +127,16 @@ class TwitterCorpusReader(CorpusReader):
         tokenizer = self._word_tokenizer
         return [tokenizer.tokenize(t) for t in tweets]
 
-
     def raw(self, fileids=None):
         """
         Return the corpora in their raw form.
         """
         if fileids is None:
             fileids = self._fileids
-        elif isinstance(fileids, string_types):
+        elif isinstance(fileids, str):
             fileids = [fileids]
         return concat([self.open(f).read() for f in fileids])
 
-
     def _read_tweets(self, stream):
         """
         Assumes that each line in ``stream`` is a JSON-serialised object.
