@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Corpus Reader Utilities
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
@@ -10,16 +10,9 @@ import os
 import bisect
 import re
 import tempfile
-from six import string_types, text_type
+import pickle
 from functools import reduce
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-
-# Use the c version of ElementTree, which is faster, if possible:
-try: from xml.etree import cElementTree as ElementTree
-except ImportError: from xml.etree import ElementTree
+from xml.etree import ElementTree
 
 from nltk.tokenize import wordpunct_tokenize
 from nltk.internals import slice_bounds
@@ -28,9 +21,10 @@ from nltk.data import SeekableUnicodeStreamReader
 from nltk.util import AbstractLazySequence, LazySubsequence, LazyConcatenation, py25
 
 ######################################################################
-#{ Corpus View
+# { Corpus View
 ######################################################################
 
+
 class StreamBackedCorpusView(AbstractLazySequence):
     """
     A 'view' of a corpus file, which acts like a sequence of tokens:
@@ -123,8 +117,8 @@ class StreamBackedCorpusView(AbstractLazySequence):
        end_toknum is the token index of the first token not in the
        block; and tokens is a list of the tokens in the block.
     """
-    def __init__(self, fileid, block_reader=None, startpos=0,
-                 encoding='utf8'):
+
+    def __init__(self, fileid, block_reader=None, startpos=0, encoding="utf8"):
         """
         Create a new corpus view, based on the file ``fileid``, and
         read with ``block_reader``.  See the class documentation
@@ -176,17 +170,19 @@ class StreamBackedCorpusView(AbstractLazySequence):
             else:
                 self._eofpos = os.stat(self._fileid).st_size
         except Exception as exc:
-            raise ValueError('Unable to open or access %r -- %s' %
-                             (fileid, exc))
+            raise ValueError("Unable to open or access %r -- %s" % (fileid, exc))
 
         # Maintain a cache of the most recently read block, to
         # increase efficiency of random access.
         self._cache = (-1, -1, None)
 
-    fileid = property(lambda self: self._fileid, doc="""
+    fileid = property(
+        lambda self: self._fileid,
+        doc="""
         The fileid of the file that is accessed by this view.
 
-        :type: str or PathPointer""")
+        :type: str or PathPointer""",
+    )
 
     def read_block(self, stream):
         """
@@ -197,7 +193,7 @@ class StreamBackedCorpusView(AbstractLazySequence):
         :param stream: an input stream
         :type stream: stream
         """
-        raise NotImplementedError('Abstract Method')
+        raise NotImplementedError("Abstract Method")
 
     def _open(self):
         """
@@ -209,9 +205,10 @@ class StreamBackedCorpusView(AbstractLazySequence):
             self._stream = self._fileid.open(self._encoding)
         elif self._encoding:
             self._stream = SeekableUnicodeStreamReader(
-                open(self._fileid, 'rb'), self._encoding)
+                open(self._fileid, "rb"), self._encoding
+            )
         else:
-            self._stream = open(self._fileid, 'rb')
+            self._stream = open(self._fileid, "rb")
 
     def close(self):
         """
@@ -230,7 +227,8 @@ class StreamBackedCorpusView(AbstractLazySequence):
         if self._len is None:
             # iterate_from() sets self._len when it reaches the end
             # of the file:
-            for tok in self.iterate_from(self._toknum[-1]): pass
+            for tok in self.iterate_from(self._toknum[-1]):
+                pass
         return self._len
 
     def __getitem__(self, i):
@@ -239,29 +237,31 @@ class StreamBackedCorpusView(AbstractLazySequence):
             # Check if it's in the cache.
             offset = self._cache[0]
             if offset <= start and stop <= self._cache[1]:
-                return self._cache[2][start-offset:stop-offset]
+                return self._cache[2][start - offset : stop - offset]
             # Construct & return the result.
             return LazySubsequence(self, start, stop)
         else:
             # Handle negative indices
-            if i < 0: i += len(self)
-            if i < 0: raise IndexError('index out of range')
+            if i < 0:
+                i += len(self)
+            if i < 0:
+                raise IndexError("index out of range")
             # Check if it's in the cache.
             offset = self._cache[0]
             if offset <= i < self._cache[1]:
-                return self._cache[2][i-offset]
+                return self._cache[2][i - offset]
             # Use iterate_from to extract it.
             try:
                 return next(self.iterate_from(i))
             except StopIteration:
-                raise IndexError('index out of range')
+                raise IndexError("index out of range")
 
     # If we wanted to be thread-safe, then this method would need to
     # do some locking.
     def iterate_from(self, start_tok):
         # Start by feeding from the cache, if possible.
         if self._cache[0] <= start_tok < self._cache[1]:
-            for tok in self._cache[2][start_tok-self._cache[0]:]:
+            for tok in self._cache[2][start_tok - self._cache[0] :]:
                 yield tok
                 start_tok += 1
 
@@ -269,11 +269,11 @@ class StreamBackedCorpusView(AbstractLazySequence):
         # our mapping, then we can jump straight to the correct block;
         # otherwise, start at the last block we've processed.
         if start_tok < self._toknum[-1]:
-            block_index = bisect.bisect_right(self._toknum, start_tok)-1
+            block_index = bisect.bisect_right(self._toknum, start_tok) - 1
             toknum = self._toknum[block_index]
             filepos = self._filepos[block_index]
         else:
-            block_index = len(self._toknum)-1
+            block_index = len(self._toknum) - 1
             toknum = self._toknum[-1]
             filepos = self._filepos[-1]
 
@@ -295,31 +295,35 @@ class StreamBackedCorpusView(AbstractLazySequence):
             self._current_blocknum = block_index
             tokens = self.read_block(self._stream)
             assert isinstance(tokens, (tuple, list, AbstractLazySequence)), (
-                'block reader %s() should return list or tuple.' %
-                self.read_block.__name__)
+                "block reader %s() should return list or tuple."
+                % self.read_block.__name__
+            )
             num_toks = len(tokens)
             new_filepos = self._stream.tell()
             assert new_filepos > filepos, (
-                'block reader %s() should consume at least 1 byte (filepos=%d)' %
-                (self.read_block.__name__, filepos))
+                "block reader %s() should consume at least 1 byte (filepos=%d)"
+                % (self.read_block.__name__, filepos)
+            )
 
             # Update our cache.
-            self._cache = (toknum, toknum+num_toks, list(tokens))
+            self._cache = (toknum, toknum + num_toks, list(tokens))
 
             # Update our mapping.
             assert toknum <= self._toknum[-1]
             if num_toks > 0:
                 block_index += 1
                 if toknum == self._toknum[-1]:
-                    assert new_filepos > self._filepos[-1] # monotonic!
+                    assert new_filepos > self._filepos[-1]  # monotonic!
                     self._filepos.append(new_filepos)
-                    self._toknum.append(toknum+num_toks)
+                    self._toknum.append(toknum + num_toks)
                 else:
                     # Check for consistency:
-                    assert new_filepos == self._filepos[block_index], (
-                        'inconsistent block reader (num chars read)')
-                    assert toknum+num_toks == self._toknum[block_index], (
-                        'inconsistent block reader (num tokens returned)')
+                    assert (
+                        new_filepos == self._filepos[block_index]
+                    ), "inconsistent block reader (num chars read)"
+                    assert (
+                        toknum + num_toks == self._toknum[block_index]
+                    ), "inconsistent block reader (num tokens returned)"
 
             # If we reached the end of the file, then update self._len
             if new_filepos == self._eofpos:
@@ -327,7 +331,7 @@ class StreamBackedCorpusView(AbstractLazySequence):
             # Generate the tokens in this block (but skip any tokens
             # before start_tok).  Note that between yields, our state
             # may be modified.
-            for tok in tokens[max(0, start_tok-toknum):]:
+            for tok in tokens[max(0, start_tok - toknum) :]:
                 yield tok
             # If we're at the end of the file, then we're done.
             assert new_filepos <= self._eofpos
@@ -347,19 +351,24 @@ class StreamBackedCorpusView(AbstractLazySequence):
     # when possible.
     def __add__(self, other):
         return concat([self, other])
+
     def __radd__(self, other):
         return concat([other, self])
+
     def __mul__(self, count):
         return concat([self] * count)
+
     def __rmul__(self, count):
         return concat([self] * count)
 
+
 class ConcatenatedCorpusView(AbstractLazySequence):
     """
     A 'view' of a corpus file that joins together one or more
     ``StreamBackedCorpusViews<StreamBackedCorpusView>``.  At most
     one file handle is left open at any time.
     """
+
     def __init__(self, corpus_views):
         self._pieces = corpus_views
         """A list of the corpus subviews that make up this
@@ -377,7 +386,8 @@ class ConcatenatedCorpusView(AbstractLazySequence):
     def __len__(self):
         if len(self._offsets) <= len(self._pieces):
             # Iterate to the end of the corpus.
-            for tok in self.iterate_from(self._offsets[-1]): pass
+            for tok in self.iterate_from(self._offsets[-1]):
+                pass
 
         return self._offsets[-1]
 
@@ -386,7 +396,7 @@ class ConcatenatedCorpusView(AbstractLazySequence):
             piece.close()
 
     def iterate_from(self, start_tok):
-        piecenum = bisect.bisect_right(self._offsets, start_tok)-1
+        piecenum = bisect.bisect_right(self._offsets, start_tok) - 1
 
         while piecenum < len(self._pieces):
             offset = self._offsets[piecenum]
@@ -399,16 +409,17 @@ class ConcatenatedCorpusView(AbstractLazySequence):
                 self._open_piece = piece
 
             # Get everything we can from this piece.
-            for tok in piece.iterate_from(max(0, start_tok-offset)):
+            for tok in piece.iterate_from(max(0, start_tok - offset)):
                 yield tok
 
             # Update the offset table.
-            if piecenum+1 == len(self._offsets):
+            if piecenum + 1 == len(self._offsets):
                 self._offsets.append(self._offsets[-1] + len(piece))
 
             # Move on to the next piece.
             piecenum += 1
 
+
 def concat(docs):
     """
     Concatenate together the contents of multiple documents from a
@@ -419,18 +430,17 @@ def concat(docs):
     if len(docs) == 1:
         return docs[0]
     if len(docs) == 0:
-        raise ValueError('concat() expects at least one object!')
+        raise ValueError("concat() expects at least one object!")
 
     types = set(d.__class__ for d in docs)
 
     # If they're all strings, use string concatenation.
-    if all(isinstance(doc, string_types) for doc in docs):
-        return ''.join(docs)
+    if all(isinstance(doc, str) for doc in docs):
+        return "".join(docs)
 
     # If they're all corpus views, then use ConcatenatedCorpusView.
     for typ in types:
-        if not issubclass(typ, (StreamBackedCorpusView,
-                                ConcatenatedCorpusView)):
+        if not issubclass(typ, (StreamBackedCorpusView, ConcatenatedCorpusView)):
             break
     else:
         return ConcatenatedCorpusView(docs)
@@ -447,23 +457,26 @@ def concat(docs):
         typ = list(types)[0]
 
         if issubclass(typ, list):
-            return reduce((lambda a,b:a+b), docs, [])
+            return reduce((lambda a, b: a + b), docs, [])
 
         if issubclass(typ, tuple):
-            return reduce((lambda a,b:a+b), docs, ())
+            return reduce((lambda a, b: a + b), docs, ())
 
         if ElementTree.iselement(typ):
-            xmltree = ElementTree.Element('documents')
-            for doc in docs: xmltree.append(doc)
+            xmltree = ElementTree.Element("documents")
+            for doc in docs:
+                xmltree.append(doc)
             return xmltree
 
     # No method found!
     raise ValueError("Don't know how to concatenate types: %r" % types)
 
+
 ######################################################################
-#{ Corpus View for Pickled Sequences
+# { Corpus View for Pickled Sequences
 ######################################################################
 
+
 class PickleCorpusView(StreamBackedCorpusView):
     """
     A stream backed corpus view for corpus files that consist of
@@ -480,6 +493,7 @@ class PickleCorpusView(StreamBackedCorpusView):
         >>> PickleCorpusView.write(feature_corpus, some_fileid)  # doctest: +SKIP
         >>> pcv = PickleCorpusView(some_fileid) # doctest: +SKIP
     """
+
     BLOCK_SIZE = 100
     PROTOCOL = -1
 
@@ -497,8 +511,10 @@ class PickleCorpusView(StreamBackedCorpusView):
     def read_block(self, stream):
         result = []
         for i in range(self.BLOCK_SIZE):
-            try: result.append(pickle.load(stream))
-            except EOFError: break
+            try:
+                result.append(pickle.load(stream))
+            except EOFError:
+                break
         return result
 
     def __del__(self):
@@ -508,16 +524,18 @@ class PickleCorpusView(StreamBackedCorpusView):
         fileid.  (This method is called whenever a
         ``PickledCorpusView`` is garbage-collected.
         """
-        if getattr(self, '_delete_on_gc'):
+        if getattr(self, "_delete_on_gc"):
             if os.path.exists(self._fileid):
-                try: os.remove(self._fileid)
-                except (OSError, IOError): pass
-        self.__dict__.clear() # make the garbage collector's job easier
+                try:
+                    os.remove(self._fileid)
+                except (OSError, IOError):
+                    pass
+        self.__dict__.clear()  # make the garbage collector's job easier
 
     @classmethod
     def write(cls, sequence, output_file):
-        if isinstance(output_file, string_types):
-            output_file = open(output_file, 'wb')
+        if isinstance(output_file, str):
+            output_file = open(output_file, "wb")
         for item in sequence:
             pickle.dump(item, output_file, cls.PROTOCOL)
 
@@ -532,71 +550,82 @@ class PickleCorpusView(StreamBackedCorpusView):
             deleted whenever this object gets garbage-collected.
         """
         try:
-            fd, output_file_name = tempfile.mkstemp('.pcv', 'nltk-')
-            output_file = os.fdopen(fd, 'wb')
+            fd, output_file_name = tempfile.mkstemp(".pcv", "nltk-")
+            output_file = os.fdopen(fd, "wb")
             cls.write(sequence, output_file)
             output_file.close()
             return PickleCorpusView(output_file_name, delete_on_gc)
         except (OSError, IOError) as e:
-            raise ValueError('Error while creating temp file: %s' % e)
-
+            raise ValueError("Error while creating temp file: %s" % e)
 
 
 ######################################################################
-#{ Block Readers
+# { Block Readers
 ######################################################################
 
+
 def read_whitespace_block(stream):
     toks = []
-    for i in range(20): # Read 20 lines at a time.
+    for i in range(20):  # Read 20 lines at a time.
         toks.extend(stream.readline().split())
     return toks
 
+
 def read_wordpunct_block(stream):
     toks = []
-    for i in range(20): # Read 20 lines at a time.
+    for i in range(20):  # Read 20 lines at a time.
         toks.extend(wordpunct_tokenize(stream.readline()))
     return toks
 
+
 def read_line_block(stream):
     toks = []
     for i in range(20):
         line = stream.readline()
-        if not line: return toks
-        toks.append(line.rstrip('\n'))
+        if not line:
+            return toks
+        toks.append(line.rstrip("\n"))
     return toks
 
+
 def read_blankline_block(stream):
-    s = ''
+    s = ""
     while True:
         line = stream.readline()
         # End of file:
         if not line:
-            if s: return [s]
-            else: return []
+            if s:
+                return [s]
+            else:
+                return []
         # Blank line:
         elif line and not line.strip():
-            if s: return [s]
+            if s:
+                return [s]
         # Other line:
         else:
             s += line
 
+
 def read_alignedsent_block(stream):
-    s = ''
+    s = ""
     while True:
         line = stream.readline()
-        if line[0] == '=' or line[0] == '\n' or line[:2] == '\r\n':
+        if line[0] == "=" or line[0] == "\n" or line[:2] == "\r\n":
             continue
         # End of file:
         if not line:
-            if s: return [s]
-            else: return []
+            if s:
+                return [s]
+            else:
+                return []
         # Other line:
         else:
             s += line
-            if re.match('^\d+-\d+', line) is not None:
+            if re.match("^\d+-\d+", line) is not None:
                 return [s]
 
+
 def read_regexp_block(stream, start_re, end_re=None):
     """
     Read a sequence of tokens from a stream, where tokens begin with
@@ -607,8 +636,10 @@ def read_regexp_block(stream, start_re, end_re=None):
     # Scan until we find a line matching the start regexp.
     while True:
         line = stream.readline()
-        if not line: return [] # end of file.
-        if re.match(start_re, line): break
+        if not line:
+            return []  # end of file.
+        if re.match(start_re, line):
+            break
 
     # Scan until we find another line matching the regexp, or EOF.
     lines = [line]
@@ -617,18 +648,19 @@ def read_regexp_block(stream, start_re, end_re=None):
         line = stream.readline()
         # End of file:
         if not line:
-            return [''.join(lines)]
+            return ["".join(lines)]
         # End of token:
         if end_re is not None and re.match(end_re, line):
-            return [''.join(lines)]
+            return ["".join(lines)]
         # Start of new token: backup to just before it starts, and
         # return the token we've already collected.
         if end_re is None and re.match(start_re, line):
             stream.seek(oldpos)
-            return [''.join(lines)]
+            return ["".join(lines)]
         # Anything else is part of the token.
         lines.append(line)
 
+
 def read_sexpr_block(stream, block_size=16384, comment_char=None):
     """
     Read a sequence of s-expressions from the stream, and leave the
@@ -650,17 +682,20 @@ def read_sexpr_block(stream, block_size=16384, comment_char=None):
     """
     start = stream.tell()
     block = stream.read(block_size)
-    encoding = getattr(stream, 'encoding', None)
-    assert encoding is not None or isinstance(block, text_type)
-    if encoding not in (None, 'utf-8'):
+    encoding = getattr(stream, "encoding", None)
+    assert encoding is not None or isinstance(block, str)
+    if encoding not in (None, "utf-8"):
         import warnings
-        warnings.warn('Parsing may fail, depending on the properties '
-                      'of the %s encoding!' % encoding)
+
+        warnings.warn(
+            "Parsing may fail, depending on the properties "
+            "of the %s encoding!" % encoding
+        )
         # (e.g., the utf-16 encoding does not work because it insists
         # on adding BOMs to the beginning of encoded strings.)
 
     if comment_char:
-        COMMENT = re.compile('(?m)^%s.*$' % re.escape(comment_char))
+        COMMENT = re.compile("(?m)^%s.*$" % re.escape(comment_char))
     while True:
         try:
             # If we're stripping comments, then make sure our block ends
@@ -673,18 +708,18 @@ def read_sexpr_block(stream, block_size=16384, comment_char=None):
             # Read the block.
             tokens, offset = _parse_sexpr_block(block)
             # Skip whitespace
-            offset = re.compile(r'\s*').search(block, offset).end()
+            offset = re.compile(r"\s*").search(block, offset).end()
 
             # Move to the end position.
             if encoding is None:
-                stream.seek(start+offset)
+                stream.seek(start + offset)
             else:
-                stream.seek(start+len(block[:offset].encode(encoding)))
+                stream.seek(start + len(block[:offset].encode(encoding)))
 
             # Return the list of tokens we processed
             return tokens
         except ValueError as e:
-            if e.args[0] == 'Block too small':
+            if e.args[0] == "Block too small":
                 next_block = stream.read(block_size)
                 if next_block:
                     block += next_block
@@ -692,45 +727,52 @@ def read_sexpr_block(stream, block_size=16384, comment_char=None):
                 else:
                     # The file ended mid-sexpr -- return what we got.
                     return [block.strip()]
-            else: raise
+            else:
+                raise
+
 
 def _sub_space(m):
     """Helper function: given a regexp match, return a string of
     spaces that's the same length as the matched string."""
-    return ' '*(m.end()-m.start())
+    return " " * (m.end() - m.start())
+
 
 def _parse_sexpr_block(block):
     tokens = []
     start = end = 0
 
     while end < len(block):
-        m = re.compile(r'\S').search(block, end)
+        m = re.compile(r"\S").search(block, end)
         if not m:
             return tokens, end
 
         start = m.start()
 
         # Case 1: sexpr is not parenthesized.
-        if m.group() != '(':
-            m2 = re.compile(r'[\s(]').search(block, start)
+        if m.group() != "(":
+            m2 = re.compile(r"[\s(]").search(block, start)
             if m2:
                 end = m2.start()
             else:
-                if tokens: return tokens, end
-                raise ValueError('Block too small')
+                if tokens:
+                    return tokens, end
+                raise ValueError("Block too small")
 
         # Case 2: parenthesized sexpr.
         else:
             nesting = 0
-            for m in re.compile(r'[()]').finditer(block, start):
-                if m.group()=='(': nesting += 1
-                else: nesting -= 1
+            for m in re.compile(r"[()]").finditer(block, start):
+                if m.group() == "(":
+                    nesting += 1
+                else:
+                    nesting -= 1
                 if nesting == 0:
                     end = m.end()
                     break
             else:
-                if tokens: return tokens, end
-                raise ValueError('Block too small')
+                if tokens:
+                    return tokens, end
+                raise ValueError("Block too small")
 
         tokens.append(block[start:end])
 
@@ -738,19 +780,23 @@ def _parse_sexpr_block(block):
 
 
 ######################################################################
-#{ Finding Corpus Items
+# { Finding Corpus Items
 ######################################################################
 
+
 def find_corpus_fileids(root, regexp):
     if not isinstance(root, PathPointer):
-        raise TypeError('find_corpus_fileids: expected a PathPointer')
-    regexp += '$'
+        raise TypeError("find_corpus_fileids: expected a PathPointer")
+    regexp += "$"
 
     # Find fileids in a zipfile: scan the zipfile's namelist.  Filter
     # out entries that end in '/' -- they're directories.
     if isinstance(root, ZipFilePathPointer):
-        fileids = [name[len(root.entry):] for name in root.zipfile.namelist()
-                 if not name.endswith('/')]
+        fileids = [
+            name[len(root.entry) :]
+            for name in root.zipfile.namelist()
+            if not name.endswith("/")
+        ]
         items = [name for name in fileids if re.match(regexp, name)]
         return sorted(items)
 
@@ -761,20 +807,25 @@ def find_corpus_fileids(root, regexp):
         # workaround for py25 which doesn't support followlinks
         kwargs = {}
         if not py25():
-            kwargs = {'followlinks': True}
+            kwargs = {"followlinks": True}
         for dirname, subdirs, fileids in os.walk(root.path, **kwargs):
-            prefix = ''.join('%s/' % p for p in _path_from(root.path, dirname))
-            items += [prefix+fileid for fileid in fileids
-                      if re.match(regexp, prefix+fileid)]
+            prefix = "".join("%s/" % p for p in _path_from(root.path, dirname))
+            items += [
+                prefix + fileid
+                for fileid in fileids
+                if re.match(regexp, prefix + fileid)
+            ]
             # Don't visit svn directories:
-            if '.svn' in subdirs: subdirs.remove('.svn')
+            if ".svn" in subdirs:
+                subdirs.remove(".svn")
         return sorted(items)
 
     else:
         raise AssertionError("Don't know how to handle %r" % root)
 
+
 def _path_from(parent, child):
-    if os.path.split(parent)[1] == '':
+    if os.path.split(parent)[1] == "":
         parent = os.path.split(parent)[0]
     path = []
     while parent != child:
@@ -783,22 +834,27 @@ def _path_from(parent, child):
         assert os.path.split(child)[0] != child
     return path
 
+
 ######################################################################
-#{ Paragraph structure in Treebank files
+# { Paragraph structure in Treebank files
 ######################################################################
 
+
 def tagged_treebank_para_block_reader(stream):
     # Read the next paragraph.
-    para = ''
+    para = ""
     while True:
         line = stream.readline()
         # End of paragraph:
-        if re.match('======+\s*$', line):
-            if para.strip(): return [para]
+        if re.match("======+\s*$", line):
+            if para.strip():
+                return [para]
         # End of file:
-        elif line == '':
-            if para.strip(): return [para]
-            else: return []
+        elif line == "":
+            if para.strip():
+                return [para]
+            else:
+                return []
         # Content line:
         else:
             para += line
