@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: Context Free Grammars
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
 #         Jason Narad <jason.narad@gmail.com>
@@ -68,15 +68,10 @@ The operation of replacing the left hand side (*lhs*) of a production
 with the right hand side (*rhs*) in a tree (*tree*) is known as
 "expanding" *lhs* to *rhs* in *tree*.
 """
-from __future__ import print_function, unicode_literals, division
-
 import re
 from functools import total_ordering
 
-from six import string_types
-
 from nltk.util import transitive_closure, invert_graph
-from nltk.compat import python_2_unicode_compatible, unicode_repr
 from nltk.internals import raise_unorderable_types
 
 from nltk.probability import ImmutableProbabilisticMixIn
@@ -89,7 +84,6 @@ from nltk.featstruct import FeatStruct, FeatDict, FeatStructReader, SLASH, TYPE
 
 
 @total_ordering
-@python_2_unicode_compatible
 class Nonterminal(object):
     """
     A non-terminal symbol for a context free grammar.  ``Nonterminal``
@@ -156,10 +150,10 @@ class Nonterminal(object):
 
         :rtype: str
         """
-        if isinstance(self._symbol, string_types):
-            return '%s' % self._symbol
+        if isinstance(self._symbol, str):
+            return "%s" % self._symbol
         else:
-            return '%s' % unicode_repr(self._symbol)
+            return "%s" % repr(self._symbol)
 
     def __str__(self):
         """
@@ -167,10 +161,10 @@ class Nonterminal(object):
 
         :rtype: str
         """
-        if isinstance(self._symbol, string_types):
-            return '%s' % self._symbol
+        if isinstance(self._symbol, str):
+            return "%s" % self._symbol
         else:
-            return '%s' % unicode_repr(self._symbol)
+            return "%s" % repr(self._symbol)
 
     def __div__(self, rhs):
         """
@@ -182,7 +176,7 @@ class Nonterminal(object):
         :type rhs: Nonterminal
         :rtype: Nonterminal
         """
-        return Nonterminal('%s/%s' % (self._symbol, rhs._symbol))
+        return Nonterminal("%s/%s" % (self._symbol, rhs._symbol))
 
     def __truediv__(self, rhs):
         """
@@ -212,8 +206,8 @@ def nonterminals(symbols):
         in the same order as the symbols names.
     :rtype: list(Nonterminal)
     """
-    if ',' in symbols:
-        symbol_list = symbols.split(',')
+    if "," in symbols:
+        symbol_list = symbols.split(",")
     else:
         symbol_list = symbols.split()
     return [Nonterminal(s.strip()) for s in symbol_list]
@@ -251,7 +245,7 @@ def is_terminal(item):
 
     :rtype: bool
     """
-    return hasattr(item, '__hash__') and not isinstance(item, Nonterminal)
+    return hasattr(item, "__hash__") and not isinstance(item, Nonterminal)
 
 
 #################################################################
@@ -260,7 +254,7 @@ def is_terminal(item):
 
 
 @total_ordering
-@python_2_unicode_compatible
+
 class Production(object):
     """
     A grammar production.  Each production maps a single symbol
@@ -290,9 +284,9 @@ class Production(object):
         :param rhs: The right-hand side of the new ``Production``.
         :type rhs: sequence(Nonterminal and terminal)
         """
-        if isinstance(rhs, string_types):
+        if isinstance(rhs, str):
             raise TypeError(
-                'production right hand side should be a list, ' 'not a string'
+                "production right hand side should be a list, " "not a string"
             )
         self._lhs = lhs
         self._rhs = tuple(rhs)
@@ -344,8 +338,8 @@ class Production(object):
 
         :rtype: str
         """
-        result = '%s -> ' % unicode_repr(self._lhs)
-        result += " ".join(unicode_repr(el) for el in self._rhs)
+        result = "%s -> " % repr(self._lhs)
+        result += " ".join(repr(el) for el in self._rhs)
         return result
 
     def __repr__(self):
@@ -354,7 +348,7 @@ class Production(object):
 
         :rtype: str
         """
-        return '%s' % self
+        return "%s" % self
 
     def __eq__(self, other):
         """
@@ -385,7 +379,7 @@ class Production(object):
         return self._hash
 
 
-@python_2_unicode_compatible
+
 class DependencyProduction(Production):
     """
     A dependency grammar production.  Each production maps a single
@@ -398,13 +392,13 @@ class DependencyProduction(Production):
 
         :rtype: str
         """
-        result = '\'%s\' ->' % (self._lhs,)
+        result = "'%s' ->" % (self._lhs,)
         for elt in self._rhs:
-            result += ' \'%s\'' % (elt,)
+            result += " '%s'" % (elt,)
         return result
 
 
-@python_2_unicode_compatible
+
 class ProbabilisticProduction(Production, ImmutableProbabilisticMixIn):
     """
     A probabilistic context free grammar production.
@@ -431,8 +425,8 @@ class ProbabilisticProduction(Production, ImmutableProbabilisticMixIn):
         Production.__init__(self, lhs, rhs)
 
     def __str__(self):
-        return Production.__unicode__(self) + (
-            ' [1.0]' if (self.prob() == 1.0) else ' [%g]' % self.prob()
+        return super().__str__() + (
+            " [1.0]" if (self.prob() == 1.0) else " [%g]" % self.prob()
         )
 
     def __eq__(self, other):
@@ -455,7 +449,7 @@ class ProbabilisticProduction(Production, ImmutableProbabilisticMixIn):
 #################################################################
 
 
-@python_2_unicode_compatible
+
 class CFG(object):
     """
     A context-free grammar.  A grammar consists of a start state and
@@ -679,7 +673,7 @@ class CFG(object):
         """
         missing = [tok for tok in tokens if not self._lexical_index.get(tok)]
         if missing:
-            missing = ', '.join('%r' % (w,) for w in missing)
+            missing = ", ".join("%r" % (w,) for w in missing)
             raise ValueError(
                 "Grammar does not cover some of the " "input words: %r." % missing
             )
@@ -753,14 +747,120 @@ class CFG(object):
         """
         return self.is_flexible_chomsky_normal_form() and self._all_unary_are_lexical
 
+    def chomsky_normal_form(self, new_token_padding="@$@", flexible=False):
+        """
+        Returns a new Grammer that is in chomsky normal
+        :param: new_token_padding
+            Customise new rule formation during binarisation
+        """
+        if self.is_chomsky_normal_form():
+            return self
+        if self.productions(empty=True):
+            raise ValueError(
+                ("Grammar has Empty rules. " "Cannot deal with them at the moment")
+            )
+
+        # check for mixed rules
+        for rule in self.productions():
+            if rule.is_lexical() and len(rule.rhs()) > 1:
+                raise ValueError(
+                    "Cannot handled mixed rule {} => {}".format(rule.lhs(), rule.rhs())
+                )
+
+        step1 = CFG.eliminate_start(self)
+        step2 = CFG.binarize(step1, new_token_padding)
+        if flexible:
+            return step2
+        step3 = CFG.remove_unitary_rules(step2)
+        return step3
+
+    @classmethod
+    def remove_unitary_rules(cls, grammar):
+        """
+        Remove nonlexical unitary rules and convert them to
+        lexical
+        """
+        result = []
+        unitary = []
+        for rule in grammar.productions():
+            if len(rule) == 1 and rule.is_nonlexical():
+                unitary.append(rule)
+            else:
+                result.append(rule)
+
+        while unitary:
+            rule = unitary.pop(0)
+            for item in grammar.productions(lhs=rule.rhs()[0]):
+                new_rule = Production(rule.lhs(), item.rhs())
+                if len(new_rule) != 1 or new_rule.is_lexical():
+                    result.append(new_rule)
+                else:
+                    unitary.append(new_rule)
+
+        n_grammar = CFG(grammar.start(), result)
+        return n_grammar
+
+    @classmethod
+    def binarize(cls, grammar, padding="@$@"):
+        """
+        Convert all non-binary rules into binary by introducing
+        new tokens.
+        Example::
+        Original:
+            A => B C D
+        After Conversion:
+            A => B A@$@B
+            A@$@B => C D
+        """
+        result = []
+
+        for rule in grammar.productions():
+            if len(rule.rhs()) > 2:
+                # this rule needs to be broken down
+                left_side = rule.lhs()
+                for k in range(0, len(rule.rhs()) - 2):
+                    tsym = rule.rhs()[k]
+                    new_sym = Nonterminal(left_side.symbol() + padding + tsym.symbol())
+                    new_production = Production(left_side, (tsym, new_sym))
+                    left_side = new_sym
+                    result.append(new_production)
+                last_prd = Production(left_side, rule.rhs()[-2:])
+                result.append(last_prd)
+            else:
+                result.append(rule)
+
+        n_grammar = CFG(grammar.start(), result)
+        return n_grammar
+
+    @classmethod
+    def eliminate_start(cls, grammar):
+        """
+        Eliminate start rule in case it appears on RHS
+        Example: S -> S0 S1 and S0 -> S1 S
+        Then another rule S0_Sigma -> S is added
+        """
+        start = grammar.start()
+        result = []
+        need_to_add = None
+        for rule in grammar.productions():
+            if start in rule.rhs():
+                need_to_add = True
+            result.append(rule)
+        if need_to_add:
+            start = Nonterminal("S0_SIGMA")
+            result.append(Production(start, [grammar.start()]))
+            n_grammar = CFG(start, result)
+            return n_grammar
+        return grammar
+
     def __repr__(self):
-        return '<Grammar with %d productions>' % len(self._productions)
+        return "<Grammar with %d productions>" % len(self._productions)
 
     def __str__(self):
-        result = 'Grammar with %d productions' % len(self._productions)
-        result += ' (start state = %r)' % self._start
+        result = "Grammar with %d productions" % len(self._productions)
+        result += " (start state = %r)" % self._start
         for production in self._productions:
-            result += '\n    %s' % production
+            result += "\n    %s" % production
         return result
 
 
@@ -844,7 +944,7 @@ class FeatureGrammar(CFG):
             )
         elif logic_parser is not None:
             raise Exception(
-                '\'logic_parser\' and \'fstruct_reader\' must ' 'not both be set'
+                "'logic_parser' and 'fstruct_reader' must " "not both be set"
             )
 
         start, productions = read_grammar(
@@ -920,7 +1020,7 @@ class FeatureGrammar(CFG):
 
 
 @total_ordering
-@python_2_unicode_compatible
+
 class FeatureValueType(object):
     """
     A helper class for ``FeatureGrammars``, designed to be different
@@ -933,7 +1033,7 @@ class FeatureValueType(object):
         self._hash = hash(value)
 
     def __repr__(self):
-        return '<%s>' % self._value
+        return "<%s>" % self._value
 
     def __eq__(self, other):
         return type(self) == type(other) and self._value == other._value
@@ -950,7 +1050,7 @@ class FeatureValueType(object):
         return self._hash
 
 
-@python_2_unicode_compatible
+
 class DependencyGrammar(object):
     """
     A dependency grammar.  A DependencyGrammar consists of a set of
@@ -970,16 +1070,16 @@ class DependencyGrammar(object):
     @classmethod
     def fromstring(cls, input):
         productions = []
-        for linenum, line in enumerate(input.split('\n')):
+        for linenum, line in enumerate(input.split("\n")):
             line = line.strip()
-            if line.startswith('#') or line == '':
+            if line.startswith("#") or line == "":
                 continue
             try:
                 productions += _read_dependency_production(line)
             except ValueError:
-                raise ValueError('Unable to parse line %s: %s' % (linenum, line))
+                raise ValueError("Unable to parse line %s: %s" % (linenum, line))
         if len(productions) == 0:
-            raise ValueError('No productions found!')
+            raise ValueError("No productions found!")
         return cls(productions)
 
     def contains(self, head, mod):
@@ -1033,19 +1133,19 @@ class DependencyGrammar(object):
 
         :rtype: str
         """
-        str = 'Dependency grammar with %d productions' % len(self._productions)
+        str = "Dependency grammar with %d productions" % len(self._productions)
         for production in self._productions:
-            str += '\n  %s' % production
+            str += "\n  %s" % production
         return str
 
     def __repr__(self):
         """
         Return a concise string representation of the ``DependencyGrammar``
         """
-        return 'Dependency grammar with %d productions' % len(self._productions)
+        return "Dependency grammar with %d productions" % len(self._productions)
+
 
 
-@python_2_unicode_compatible
 class ProbabilisticDependencyGrammar(object):
     """
 
@@ -1079,24 +1179,24 @@ class ProbabilisticDependencyGrammar(object):
 
         :rtype: str
         """
-        str = 'Statistical dependency grammar with %d productions' % len(
+        str = "Statistical dependency grammar with %d productions" % len(
             self._productions
         )
         for production in self._productions:
-            str += '\n  %s' % production
-        str += '\nEvents:'
+            str += "\n  %s" % production
+        str += "\nEvents:"
         for event in self._events:
-            str += '\n  %d:%s' % (self._events[event], event)
-        str += '\nTags:'
+            str += "\n  %d:%s" % (self._events[event], event)
+        str += "\nTags:"
         for tag_word in self._tags:
-            str += '\n %s:\t(%s)' % (tag_word, self._tags[tag_word])
+            str += "\n %s:\t(%s)" % (tag_word, self._tags[tag_word])
         return str
 
     def __repr__(self):
         """
         Return a concise string representation of the ``ProbabilisticDependencyGrammar``
         """
-        return 'Statistical Dependency grammar with %d productions' % len(
+        return "Statistical Dependency grammar with %d productions" % len(
             self._productions
         )
 
@@ -1231,10 +1331,10 @@ def _read_fcfg_production(input, fstruct_reader):
 
 # Parsing generic grammars
 
-_ARROW_RE = re.compile(r'\s* -> \s*', re.VERBOSE)
-_PROBABILITY_RE = re.compile(r'( \[ [\d\.]+ \] ) \s*', re.VERBOSE)
+_ARROW_RE = re.compile(r"\s* -> \s*", re.VERBOSE)
+_PROBABILITY_RE = re.compile(r"( \[ [\d\.]+ \] ) \s*", re.VERBOSE)
 _TERMINAL_RE = re.compile(r'( "[^"]+" | \'[^\']+\' ) \s*', re.VERBOSE)
-_DISJUNCTION_RE = re.compile(r'\| \s*', re.VERBOSE)
+_DISJUNCTION_RE = re.compile(r"\| \s*", re.VERBOSE)
 
 
 def _read_production(line, nonterm_parser, probabilistic=False):
@@ -1250,7 +1350,7 @@ def _read_production(line, nonterm_parser, probabilistic=False):
     # Skip over the arrow.
     m = _ARROW_RE.match(line, pos)
     if not m:
-        raise ValueError('Expected an arrow')
+        raise ValueError("Expected an arrow")
     pos = m.end()
 
     # Parse the right hand side.
@@ -1264,20 +1364,20 @@ def _read_production(line, nonterm_parser, probabilistic=False):
             probabilities[-1] = float(m.group(1)[1:-1])
             if probabilities[-1] > 1.0:
                 raise ValueError(
-                    'Production probability %f, '
-                    'should not be greater than 1.0' % (probabilities[-1],)
+                    "Production probability %f, "
+                    "should not be greater than 1.0" % (probabilities[-1],)
                 )
 
         # String -- add terminal.
-        elif line[pos] in "\'\"":
+        elif line[pos] in "'\"":
             m = _TERMINAL_RE.match(line, pos)
             if not m:
-                raise ValueError('Unterminated string')
+                raise ValueError("Unterminated string")
             rhsides[-1].append(m.group(1)[1:-1])
             pos = m.end()
 
         # Vertical bar -- start new rhside.
-        elif line[pos] == '|':
+        elif line[pos] == "|":
             m = _DISJUNCTION_RE.match(line, pos)
             probabilities.append(0.0)
             rhsides.append([])
@@ -1319,51 +1419,51 @@ def read_grammar(input, nonterm_parser, probabilistic=False, encoding=None):
     """
     if encoding is not None:
         input = input.decode(encoding)
-    if isinstance(input, string_types):
-        lines = input.split('\n')
+    if isinstance(input, str):
+        lines = input.split("\n")
     else:
         lines = input
 
     start = None
     productions = []
-    continue_line = ''
+    continue_line = ""
     for linenum, line in enumerate(lines):
         line = continue_line + line.strip()
-        if line.startswith('#') or line == '':
+        if line.startswith("#") or line == "":
             continue
-        if line.endswith('\\'):
-            continue_line = line[:-1].rstrip() + ' '
+        if line.endswith("\\"):
+            continue_line = line[:-1].rstrip() + " "
             continue
-        continue_line = ''
+        continue_line = ""
         try:
-            if line[0] == '%':
+            if line[0] == "%":
                 directive, args = line[1:].split(None, 1)
-                if directive == 'start':
+                if directive == "start":
                     start, pos = nonterm_parser(args, 0)
                     if pos != len(args):
-                        raise ValueError('Bad argument to start directive')
+                        raise ValueError("Bad argument to start directive")
                 else:
-                    raise ValueError('Bad directive')
+                    raise ValueError("Bad directive")
             else:
                 # expand out the disjunctions on the RHS
                 productions += _read_production(line, nonterm_parser, probabilistic)
         except ValueError as e:
-            raise ValueError('Unable to parse line %s: %s\n%s' % (linenum + 1, line, e))
+            raise ValueError("Unable to parse line %s: %s\n%s" % (linenum + 1, line, e))
 
     if not productions:
-        raise ValueError('No productions found!')
+        raise ValueError("No productions found!")
     if not start:
         start = productions[0].lhs()
     return (start, productions)
 
 
-_STANDARD_NONTERM_RE = re.compile('( [\w/][\w/^<>-]* ) \s*', re.VERBOSE)
+_STANDARD_NONTERM_RE = re.compile("( [\w/][\w/^<>-]* ) \s*", re.VERBOSE)
 
 
 def standard_nonterm_parser(string, pos):
     m = _STANDARD_NONTERM_RE.match(string, pos)
     if not m:
-        raise ValueError('Expected a nonterminal, found: ' + string[pos:])
+        raise ValueError("Expected a nonterminal, found: " + string[pos:])
     return (Nonterminal(m.group(1)), m.end())
 
 
@@ -1372,7 +1472,7 @@ def standard_nonterm_parser(string, pos):
 #################################################################
 
 _READ_DG_RE = re.compile(
-    r'''^\s*                # leading whitespace
+    r"""^\s*                # leading whitespace
                               ('[^']+')\s*        # single-quoted lhs
                               (?:[-=]+>)\s*        # arrow
                               (?:(                 # rhs:
@@ -1381,24 +1481,24 @@ _READ_DG_RE = re.compile(
                                  | \|              # disjunction
                                  )
                                  \s*)              # trailing space
-                                 *$''',  # zero or more copies
+                                 *$""",  # zero or more copies
     re.VERBOSE,
 )
-_SPLIT_DG_RE = re.compile(r'''('[^']'|[-=]+>|"[^"]+"|'[^']+'|\|)''')
+_SPLIT_DG_RE = re.compile(r"""('[^']'|[-=]+>|"[^"]+"|'[^']+'|\|)""")
 
 
 def _read_dependency_production(s):
     if not _READ_DG_RE.match(s):
-        raise ValueError('Bad production string')
+        raise ValueError("Bad production string")
     pieces = _SPLIT_DG_RE.split(s)
     pieces = [p for i, p in enumerate(pieces) if i % 2 == 1]
-    lhside = pieces[0].strip('\'\"')
+    lhside = pieces[0].strip("'\"")
     rhsides = [[]]
     for piece in pieces[2:]:
-        if piece == '|':
+        if piece == "|":
             rhsides.append([])
         else:
-            rhsides[-1].append(piece.strip('\'\"'))
+            rhsides[-1].append(piece.strip("'\""))
     return [DependencyProduction(lhside, rhside) for rhside in rhsides]
 
 
@@ -1415,12 +1515,12 @@ def cfg_demo():
     from nltk import nonterminals, Production, CFG
 
     # Create some nonterminals
-    S, NP, VP, PP = nonterminals('S, NP, VP, PP')
-    N, V, P, Det = nonterminals('N, V, P, Det')
+    S, NP, VP, PP = nonterminals("S, NP, VP, PP")
+    N, V, P, Det = nonterminals("N, V, P, Det")
     VP_slash_NP = VP / NP
 
-    print('Some nonterminals:', [S, NP, VP, PP, N, V, P, Det, VP / NP])
-    print('    S.symbol() =>', repr(S.symbol()))
+    print("Some nonterminals:", [S, NP, VP, PP, N, V, P, Det, VP / NP])
+    print("    S.symbol() =>", repr(S.symbol()))
     print()
 
     print(Production(S, [NP]))
@@ -1439,11 +1539,11 @@ def cfg_demo():
     """
     )
 
-    print('A Grammar:', repr(grammar))
-    print('    grammar.start()       =>', repr(grammar.start()))
-    print('    grammar.productions() =>', end=' ')
+    print("A Grammar:", repr(grammar))
+    print("    grammar.start()       =>", repr(grammar.start()))
+    print("    grammar.productions() =>", end=" ")
     # Use string.replace(...) is to line-wrap the output.
-    print(repr(grammar.productions()).replace(',', ',\n' + ' ' * 25))
+    print(repr(grammar.productions()).replace(",", ",\n" + " " * 25))
     print()
 
 
@@ -1502,18 +1602,18 @@ def pcfg_demo():
     pcfg_prods = toy_pcfg1.productions()
 
     pcfg_prod = pcfg_prods[2]
-    print('A PCFG production:', repr(pcfg_prod))
-    print('    pcfg_prod.lhs()  =>', repr(pcfg_prod.lhs()))
-    print('    pcfg_prod.rhs()  =>', repr(pcfg_prod.rhs()))
-    print('    pcfg_prod.prob() =>', repr(pcfg_prod.prob()))
+    print("A PCFG production:", repr(pcfg_prod))
+    print("    pcfg_prod.lhs()  =>", repr(pcfg_prod.lhs()))
+    print("    pcfg_prod.rhs()  =>", repr(pcfg_prod.rhs()))
+    print("    pcfg_prod.prob() =>", repr(pcfg_prod.prob()))
     print()
 
     grammar = toy_pcfg2
-    print('A PCFG grammar:', repr(grammar))
-    print('    grammar.start()       =>', repr(grammar.start()))
-    print('    grammar.productions() =>', end=' ')
+    print("A PCFG grammar:", repr(grammar))
+    print("    grammar.start()       =>", repr(grammar.start()))
+    print("    grammar.productions() =>", end=" ")
     # Use .replace(...) is to line-wrap the output.
-    print(repr(grammar.productions()).replace(',', ',\n' + ' ' * 26))
+    print(repr(grammar.productions()).replace(",", ",\n" + " " * 26))
     print()
 
     # extract productions from three trees and induce the PCFG
@@ -1528,7 +1628,7 @@ def pcfg_demo():
 
         productions += tree.productions()
 
-    S = Nonterminal('S')
+    S = Nonterminal("S")
     grammar = induce_pcfg(S, productions)
     print(grammar)
     print()
@@ -1550,7 +1650,7 @@ def pcfg_demo():
 def fcfg_demo():
     import nltk.data
 
-    g = nltk.data.load('grammars/book_grammars/feat0.fcfg')
+    g = nltk.data.load("grammars/book_grammars/feat0.fcfg")
     print(g)
     print()
 
@@ -1606,19 +1706,19 @@ def demo():
     sdg_demo()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
 
 __all__ = [
-    'Nonterminal',
-    'nonterminals',
-    'CFG',
-    'Production',
-    'PCFG',
-    'ProbabilisticProduction',
-    'DependencyGrammar',
-    'DependencyProduction',
-    'ProbabilisticDependencyGrammar',
-    'induce_pcfg',
-    'read_grammar',
+    "Nonterminal",
+    "nonterminals",
+    "CFG",
+    "Production",
+    "PCFG",
+    "ProbabilisticProduction",
+    "DependencyGrammar",
+    "DependencyProduction",
+    "ProbabilisticDependencyGrammar",
+    "induce_pcfg",
+    "read_grammar",
 ]
