@@ -1,19 +1,16 @@
 # Natural Language Toolkit: Evaluation
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, division
 
 from math import fabs
 import operator
 from random import shuffle
 from functools import reduce
 
-from six.moves import range, zip
-
 try:
     from scipy.stats.stats import betai
 except ImportError:
@@ -55,8 +52,8 @@ def precision(reference, test):
     :param test: A set of values to compare against the reference set.
     :rtype: float or None
     """
-    if not hasattr(reference, 'intersection') or not hasattr(test, 'intersection'):
-        raise TypeError('reference and test should be sets')
+    if not hasattr(reference, "intersection") or not hasattr(test, "intersection"):
+        raise TypeError("reference and test should be sets")
 
     if len(test) == 0:
         return None
@@ -77,8 +74,8 @@ def recall(reference, test):
     :param test: A set of values to compare against the reference set.
     :rtype: float or None
     """
-    if not hasattr(reference, 'intersection') or not hasattr(test, 'intersection'):
-        raise TypeError('reference and test should be sets')
+    if not hasattr(reference, "intersection") or not hasattr(test, "intersection"):
+        raise TypeError("reference and test should be sets")
 
     if len(reference) == 0:
         return None
@@ -160,20 +157,20 @@ def approxrand(a, b, **kwargs):
     :param b: another list of independently generated test values
     :type b: list
     """
-    shuffles = kwargs.get('shuffles', 999)
+    shuffles = kwargs.get("shuffles", 999)
     # there's no point in trying to shuffle beyond all possible permutations
     shuffles = min(shuffles, reduce(operator.mul, range(1, len(a) + len(b) + 1)))
-    stat = kwargs.get('statistic', lambda lst: sum(lst) / len(lst))
-    verbose = kwargs.get('verbose', False)
+    stat = kwargs.get("statistic", lambda lst: sum(lst) / len(lst))
+    verbose = kwargs.get("verbose", False)
 
     if verbose:
-        print('shuffles: %d' % shuffles)
+        print("shuffles: %d" % shuffles)
 
     actual_stat = fabs(stat(a) - stat(b))
 
     if verbose:
-        print('actual statistic: %f' % actual_stat)
-        print('-' * 60)
+        print("actual statistic: %f" % actual_stat)
+        print("-" * 60)
 
     c = 1e-100
     lst = LazyConcatenation([a, b])
@@ -181,7 +178,7 @@ def approxrand(a, b, **kwargs):
 
     for i in range(shuffles):
         if verbose and i % 10 == 0:
-            print('shuffle: %d' % i)
+            print("shuffle: %d" % i)
 
         shuffle(indices)
 
@@ -193,14 +190,14 @@ def approxrand(a, b, **kwargs):
             c += 1
 
         if verbose and i % 10 == 0:
-            print('pseudo-statistic: %f' % pseudo_stat)
-            print('significance: %f' % ((c + 1) / (i + 1)))
-            print('-' * 60)
+            print("pseudo-statistic: %f" % pseudo_stat)
+            print("significance: %f" % ((c + 1) / (i + 1)))
+            print("-" * 60)
 
     significance = (c + 1) / (shuffles + 1)
 
     if verbose:
-        print('significance: %f' % significance)
+        print("significance: %f" % significance)
         if betai:
             for phi in [0.01, 0.05, 0.10, 0.15, 0.25, 0.50]:
                 print("prob(phi<=%f): %f" % (phi, betai(c, shuffles, phi)))
@@ -209,23 +206,23 @@ def approxrand(a, b, **kwargs):
 
 
 def demo():
-    print('-' * 75)
-    reference = 'DET NN VB DET JJ NN NN IN DET NN'.split()
-    test = 'DET VB VB DET NN NN NN IN DET NN'.split()
-    print('Reference =', reference)
-    print('Test    =', test)
-    print('Accuracy:', accuracy(reference, test))
+    print("-" * 75)
+    reference = "DET NN VB DET JJ NN NN IN DET NN".split()
+    test = "DET VB VB DET NN NN NN IN DET NN".split()
+    print("Reference =", reference)
+    print("Test    =", test)
+    print("Accuracy:", accuracy(reference, test))
 
-    print('-' * 75)
+    print("-" * 75)
     reference_set = set(reference)
     test_set = set(test)
-    print('Reference =', reference_set)
-    print('Test =   ', test_set)
-    print('Precision:', precision(reference_set, test_set))
-    print('   Recall:', recall(reference_set, test_set))
-    print('F-Measure:', f_measure(reference_set, test_set))
-    print('-' * 75)
+    print("Reference =", reference_set)
+    print("Test =   ", test_set)
+    print("Precision:", precision(reference_set, test_set))
+    print("   Recall:", recall(reference_set, test_set))
+    print("F-Measure:", f_measure(reference_set, test_set))
+    print("-" * 75)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
