@@ -1,7 +1,7 @@
 # Natural Language Toolkit: Chat-80 KB Reader
 # See http://www.w3.org/TR/swbp-skos-core-guide/
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>,
 # URL: <http://nltk.sourceforge.net>
 # For license information, see LICENSE.TXT
@@ -122,104 +122,133 @@ The set of rules is written to the file ``chat_pnames.cfg`` in the
 current directory.
 
 """
-from __future__ import print_function, unicode_literals
 
 import re
 import shelve
 import os
 import sys
 
-from six import string_types
-
 import nltk.data
-from nltk.compat import python_2_unicode_compatible
 
 ###########################################################################
 # Chat-80 relation metadata bundles needed to build the valuation
 ###########################################################################
 
-borders = {'rel_name': 'borders',
-           'closures': ['symmetric'],
-           'schema': ['region', 'border'],
-           'filename': 'borders.pl'}
+borders = {
+    "rel_name": "borders",
+    "closures": ["symmetric"],
+    "schema": ["region", "border"],
+    "filename": "borders.pl",
+}
 
-contains = {'rel_name': 'contains0',
-            'closures': ['transitive'],
-            'schema': ['region', 'contain'],
-            'filename': 'contain.pl'}
+contains = {
+    "rel_name": "contains0",
+    "closures": ["transitive"],
+    "schema": ["region", "contain"],
+    "filename": "contain.pl",
+}
 
-city = {'rel_name': 'city',
-        'closures': [],
-        'schema': ['city', 'country', 'population'],
-        'filename': 'cities.pl'}
+city = {
+    "rel_name": "city",
+    "closures": [],
+    "schema": ["city", "country", "population"],
+    "filename": "cities.pl",
+}
 
-country = {'rel_name': 'country',
-           'closures': [],
-           'schema': ['country', 'region', 'latitude', 'longitude',
-                      'area', 'population', 'capital', 'currency'],
-           'filename': 'countries.pl'}
+country = {
+    "rel_name": "country",
+    "closures": [],
+    "schema": [
+        "country",
+        "region",
+        "latitude",
+        "longitude",
+        "area",
+        "population",
+        "capital",
+        "currency",
+    ],
+    "filename": "countries.pl",
+}
 
-circle_of_lat = {'rel_name': 'circle_of_latitude',
-                 'closures': [],
-                 'schema': ['circle_of_latitude', 'degrees'],
-                 'filename': 'world1.pl'}
+circle_of_lat = {
+    "rel_name": "circle_of_latitude",
+    "closures": [],
+    "schema": ["circle_of_latitude", "degrees"],
+    "filename": "world1.pl",
+}
 
-circle_of_long = {'rel_name': 'circle_of_longitude',
-                 'closures': [],
-                 'schema': ['circle_of_longitude', 'degrees'],
-                 'filename': 'world1.pl'}
+circle_of_long = {
+    "rel_name": "circle_of_longitude",
+    "closures": [],
+    "schema": ["circle_of_longitude", "degrees"],
+    "filename": "world1.pl",
+}
 
-continent = {'rel_name': 'continent',
-             'closures': [],
-             'schema': ['continent'],
-             'filename': 'world1.pl'}
+continent = {
+    "rel_name": "continent",
+    "closures": [],
+    "schema": ["continent"],
+    "filename": "world1.pl",
+}
 
-region = {'rel_name': 'in_continent',
-          'closures': [],
-          'schema': ['region', 'continent'],
-          'filename': 'world1.pl'}
+region = {
+    "rel_name": "in_continent",
+    "closures": [],
+    "schema": ["region", "continent"],
+    "filename": "world1.pl",
+}
 
-ocean = {'rel_name': 'ocean',
-         'closures': [],
-         'schema': ['ocean'],
-         'filename': 'world1.pl'}
+ocean = {
+    "rel_name": "ocean",
+    "closures": [],
+    "schema": ["ocean"],
+    "filename": "world1.pl",
+}
 
-sea = {'rel_name': 'sea',
-       'closures': [],
-       'schema': ['sea'],
-       'filename': 'world1.pl'}
+sea = {"rel_name": "sea", "closures": [], "schema": ["sea"], "filename": "world1.pl"}
 
 
-
-items = ['borders', 'contains', 'city', 'country', 'circle_of_lat',
-         'circle_of_long', 'continent', 'region', 'ocean', 'sea']
+items = [
+    "borders",
+    "contains",
+    "city",
+    "country",
+    "circle_of_lat",
+    "circle_of_long",
+    "continent",
+    "region",
+    "ocean",
+    "sea",
+]
 items = tuple(sorted(items))
 
 item_metadata = {
-    'borders': borders,
-    'contains': contains,
-    'city': city,
-    'country': country,
-    'circle_of_lat': circle_of_lat,
-    'circle_of_long': circle_of_long,
-    'continent': continent,
-    'region': region,
-    'ocean': ocean,
-    'sea': sea
-    }
+    "borders": borders,
+    "contains": contains,
+    "city": city,
+    "country": country,
+    "circle_of_lat": circle_of_lat,
+    "circle_of_long": circle_of_long,
+    "continent": continent,
+    "region": region,
+    "ocean": ocean,
+    "sea": sea,
+}
 
 rels = item_metadata.values()
 
-not_unary = ['borders.pl', 'contain.pl']
+not_unary = ["borders.pl", "contain.pl"]
 
 ###########################################################################
 
-@python_2_unicode_compatible
+
 class Concept(object):
     """
     A Concept class, loosely based on SKOS
     (http://www.w3.org/TR/swbp-skos-core-guide/).
     """
+
     def __init__(self, prefLabel, arity, altLabels=[], closures=[], extension=set()):
         """
         :param prefLabel: the preferred label for the concept
@@ -238,21 +267,24 @@ class Concept(object):
         self.arity = arity
         self.altLabels = altLabels
         self.closures = closures
-        #keep _extension internally as a set
+        # keep _extension internally as a set
         self._extension = extension
-        #public access is via a list (for slicing)
+        # public access is via a list (for slicing)
         self.extension = sorted(list(extension))
 
     def __str__(self):
-        #_extension = ''
-        #for element in sorted(self.extension):
-            #if isinstance(element, tuple):
-                #element = '(%s, %s)' % (element)
-            #_extension += element + ', '
-        #_extension = _extension[:-1]
+        # _extension = ''
+        # for element in sorted(self.extension):
+        # if isinstance(element, tuple):
+        # element = '(%s, %s)' % (element)
+        # _extension += element + ', '
+        # _extension = _extension[:-1]
 
-        return "Label = '%s'\nArity = %s\nExtension = %s" % \
-               (self.prefLabel, self.arity, self.extension)
+        return "Label = '%s'\nArity = %s\nExtension = %s" % (
+            self.prefLabel,
+            self.arity,
+            self.extension,
+        )
 
     def __repr__(self):
         return "Concept('%s')" % self.prefLabel
@@ -270,7 +302,6 @@ class Concept(object):
         self.extension = sorted(list(self._extension))
         return self._extension
 
-
     def _make_graph(self, s):
         """
         Convert a set of pairs into an adjacency linked list encoding of a graph.
@@ -306,7 +337,6 @@ class Concept(object):
                 pairs.append((node, adjacent))
         return set(pairs)
 
-
     def close(self):
         """
         Close a binary relation in the ``Concept``'s extension set.
@@ -315,18 +345,18 @@ class Concept(object):
                  relation is closed under a given property
         """
         from nltk.sem import is_rel
+
         assert is_rel(self._extension)
-        if 'symmetric' in self.closures:
+        if "symmetric" in self.closures:
             pairs = []
             for (x, y) in self._extension:
                 pairs.append((y, x))
             sym = set(pairs)
             self._extension = self._extension.union(sym)
-        if 'transitive' in self.closures:
-            all =  self._make_graph(self._extension)
-            closed =  self._transclose(all)
+        if "transitive" in self.closures:
+            all = self._make_graph(self._extension)
+            closed = self._transclose(all)
             trans = self._make_pairs(closed)
-            #print sorted(trans)
             self._extension = self._extension.union(trans)
         self.extension = sorted(list(self._extension))
 
@@ -370,6 +400,7 @@ def clause2concepts(filename, rel_name, schema, closures=[]):
 
     return concepts
 
+
 def cities2table(filename, rel_name, dbname, verbose=False, setup=False):
     """
     Convert a file of Prolog clauses into a database table.
@@ -389,16 +420,19 @@ def cities2table(filename, rel_name, dbname, verbose=False, setup=False):
     :type schema: str
     """
     import sqlite3
+
     records = _str2records(filename, rel_name)
-    connection =  sqlite3.connect(dbname)
+    connection = sqlite3.connect(dbname)
     cur = connection.cursor()
     if setup:
-        cur.execute('''CREATE TABLE city_table
-        (City text, Country text, Population int)''')
+        cur.execute(
+            """CREATE TABLE city_table
+        (City text, Country text, Population int)"""
+        )
 
     table_name = "city_table"
     for t in records:
-        cur.execute('insert into %s values (?,?,?)' % table_name, t)
+        cur.execute("insert into %s values (?,?,?)" % table_name, t)
         if verbose:
             print("inserting values into %s: " % table_name, t)
     connection.commit()
@@ -406,6 +440,7 @@ def cities2table(filename, rel_name, dbname, verbose=False, setup=False):
         print("Committing update to %s" % dbname)
     cur.close()
 
+
 def sql_query(dbname, query):
     """
     Execute an SQL query over a database.
@@ -415,16 +450,21 @@ def sql_query(dbname, query):
     :type rel_name: str
     """
     import sqlite3
+
     try:
         path = nltk.data.find(dbname)
-        connection =  sqlite3.connect(str(path))
+        connection = sqlite3.connect(str(path))
         cur = connection.cursor()
         return cur.execute(query)
     except (ValueError, sqlite3.OperationalError):
         import warnings
-        warnings.warn("Make sure the database file %s is installed and uncompressed." % dbname)
+
+        warnings.warn(
+            "Make sure the database file %s is installed and uncompressed." % dbname
+        )
         raise
 
+
 def _str2records(filename, rel):
     """
     Read a file into memory and convert each relation clause into a list.
@@ -433,12 +473,13 @@ def _str2records(filename, rel):
     contents = nltk.data.load("corpora/chat80/%s" % filename, format="text")
     for line in contents.splitlines():
         if line.startswith(rel):
-            line = re.sub(rel+r'\(', '', line)
-            line = re.sub(r'\)\.$', '', line)
-            record = line.split(',')
+            line = re.sub(rel + r"\(", "", line)
+            line = re.sub(r"\)\.$", "", line)
+            record = line.split(",")
             recs.append(record)
     return recs
 
+
 def unary_concept(label, subj, records):
     """
     Make a unary concept out of the primary key in a record.
@@ -461,6 +502,7 @@ def unary_concept(label, subj, records):
         c.augment(record[subj])
     return c
 
+
 def binary_concept(label, closures, subj, obj, records):
     """
     Make a binary concept out of the primary key and another field in a record.
@@ -489,8 +531,8 @@ def binary_concept(label, closures, subj, obj, records):
     :return: ``Concept`` of arity 2
     :rtype: Concept
     """
-    if not label == 'border' and not label == 'contain':
-        label = label + '_of'
+    if not label == "border" and not label == "contain":
+        label = label + "_of"
     c = Concept(label, arity=2, closures=closures, extension=set())
     for record in records:
         c.augment((record[subj], record[obj]))
@@ -511,15 +553,15 @@ def process_bundle(rels):
     """
     concepts = {}
     for rel in rels:
-        rel_name = rel['rel_name']
-        closures = rel['closures']
-        schema = rel['schema']
-        filename = rel['filename']
+        rel_name = rel["rel_name"]
+        closures = rel["closures"]
+        schema = rel["schema"]
+        filename = rel["filename"]
 
         concept_list = clause2concepts(filename, rel_name, schema, closures)
         for c in concept_list:
             label = c.prefLabel
-            if (label in concepts):
+            if label in concepts:
                 for data in c.extension:
                     concepts[label].augment(data)
                 concepts[label].close()
@@ -543,9 +585,11 @@ def make_valuation(concepts, read=False, lexicon=False):
 
     for c in concepts:
         vals.append((c.prefLabel, c.extension))
-    if lexicon: read = True
+    if lexicon:
+        read = True
     if read:
         from nltk.sem import Valuation
+
         val = Valuation({})
         val.update(vals)
         # add labels for individuals
@@ -568,7 +612,7 @@ def val_dump(rels, db):
     """
     concepts = process_bundle(rels).values()
     valuation = make_valuation(concepts, read=True)
-    db_out = shelve.open(db, 'n')
+    db_out = shelve.open(db, "n")
 
     db_out.update(valuation)
 
@@ -583,33 +627,34 @@ def val_load(db):
                The suffix '.db' should be omitted from the name.
     :type db: str
     """
-    dbname = db+".db"
+    dbname = db + ".db"
 
     if not os.access(dbname, os.R_OK):
         sys.exit("Cannot read file: %s" % dbname)
     else:
         db_in = shelve.open(db)
         from nltk.sem import Valuation
+
         val = Valuation(db_in)
-#        val.read(db_in.items())
+        #        val.read(db_in.items())
         return val
 
 
-#def alpha(str):
-    #"""
-    #Utility to filter out non-alphabetic constants.
+# def alpha(str):
+# """
+# Utility to filter out non-alphabetic constants.
 
-    #:param str: candidate constant
-    #:type str: string
-    #:rtype: bool
-    #"""
-    #try:
-        #int(str)
-        #return False
-    #except ValueError:
-        ## some unknown values in records are labeled '?'
-        #if not str == '?':
-            #return True
+#:param str: candidate constant
+#:type str: string
+#:rtype: bool
+# """
+# try:
+# int(str)
+# return False
+# except ValueError:
+## some unknown values in records are labeled '?'
+# if not str == '?':
+# return True
 
 
 def label_indivs(valuation, lexicon=False):
@@ -629,12 +674,13 @@ def label_indivs(valuation, lexicon=False):
     pairs = [(e, e) for e in domain]
     if lexicon:
         lex = make_lex(domain)
-        with open("chat_pnames.cfg", 'w') as outfile:
+        with open("chat_pnames.cfg", "w") as outfile:
             outfile.writelines(lex)
     # read the pairs into the valuation
     valuation.update(pairs)
     return valuation
 
+
 def make_lex(symbols):
     """
     Create lexical CFG rules for each individual symbol.
@@ -657,9 +703,9 @@ def make_lex(symbols):
     template = "PropN[num=sg, sem=<\P.(P %s)>] -> '%s'\n"
 
     for s in symbols:
-        parts = s.split('_')
+        parts = s.split("_")
         caps = [p.capitalize() for p in parts]
-        pname = '_'.join(caps)
+        pname = "_".join(caps)
         rule = template % (s, pname)
         lex.append(rule)
     return lex
@@ -669,7 +715,8 @@ def make_lex(symbols):
 # Interface function to emulate other corpus readers
 ###########################################################################
 
-def concepts(items = items):
+
+def concepts(items=items):
     """
     Build a list of concepts corresponding to the relation names in ``items``.
 
@@ -678,7 +725,8 @@ def concepts(items = items):
     :return: the ``Concept`` objects which are extracted from the relations
     :rtype: list(Concept)
     """
-    if isinstance(items, string_types): items = (items,)
+    if isinstance(items, str):
+        items = (items,)
 
     rels = [item_metadata[r] for r in items]
 
@@ -686,53 +734,80 @@ def concepts(items = items):
     return concept_map.values()
 
 
-
-
 ###########################################################################
 
 
 def main():
     import sys
     from optparse import OptionParser
-    description = \
-    """
+
+    description = """
 Extract data from the Chat-80 Prolog files and convert them into a
 Valuation object for use in the NLTK semantics package.
     """
 
     opts = OptionParser(description=description)
     opts.set_defaults(verbose=True, lex=False, vocab=False)
-    opts.add_option("-s", "--store", dest="outdb",
-                    help="store a valuation in DB", metavar="DB")
-    opts.add_option("-l", "--load", dest="indb",
-                    help="load a stored valuation from DB", metavar="DB")
-    opts.add_option("-c", "--concepts", action="store_true",
-                    help="print concepts instead of a valuation")
-    opts.add_option("-r", "--relation", dest="label",
-                    help="print concept with label REL (check possible labels with '-v' option)", metavar="REL")
-    opts.add_option("-q", "--quiet", action="store_false", dest="verbose",
-                    help="don't print out progress info")
-    opts.add_option("-x", "--lex", action="store_true", dest="lex",
-                    help="write a file of lexical entries for country names, then exit")
-    opts.add_option("-v", "--vocab", action="store_true", dest="vocab",
-                        help="print out the vocabulary of concept labels and their arity, then exit")
+    opts.add_option(
+        "-s", "--store", dest="outdb", help="store a valuation in DB", metavar="DB"
+    )
+    opts.add_option(
+        "-l",
+        "--load",
+        dest="indb",
+        help="load a stored valuation from DB",
+        metavar="DB",
+    )
+    opts.add_option(
+        "-c",
+        "--concepts",
+        action="store_true",
+        help="print concepts instead of a valuation",
+    )
+    opts.add_option(
+        "-r",
+        "--relation",
+        dest="label",
+        help="print concept with label REL (check possible labels with '-v' option)",
+        metavar="REL",
+    )
+    opts.add_option(
+        "-q",
+        "--quiet",
+        action="store_false",
+        dest="verbose",
+        help="don't print out progress info",
+    )
+    opts.add_option(
+        "-x",
+        "--lex",
+        action="store_true",
+        dest="lex",
+        help="write a file of lexical entries for country names, then exit",
+    )
+    opts.add_option(
+        "-v",
+        "--vocab",
+        action="store_true",
+        dest="vocab",
+        help="print out the vocabulary of concept labels and their arity, then exit",
+    )
 
     (options, args) = opts.parse_args()
     if options.outdb and options.indb:
         opts.error("Options --store and --load are mutually exclusive")
 
-
     if options.outdb:
         # write the valuation to a persistent database
         if options.verbose:
-            outdb = options.outdb+".db"
+            outdb = options.outdb + ".db"
             print("Dumping a valuation to %s" % outdb)
         val_dump(rels, options.outdb)
         sys.exit(0)
     else:
         # try to read in a valuation from a database
         if options.indb is not None:
-            dbname = options.indb+".db"
+            dbname = options.indb + ".db"
             if not os.access(dbname, os.R_OK):
                 sys.exit("Cannot read file: %s" % dbname)
             else:
@@ -773,10 +848,10 @@ def sql_demo():
     """
     print()
     print("Using SQL to extract rows from 'city.db' RDB.")
-    for row in sql_query('corpora/city_database/city.db', "SELECT * FROM city_table"):
+    for row in sql_query("corpora/city_database/city.db", "SELECT * FROM city_table"):
         print(row)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
     sql_demo()
