@@ -2,7 +2,7 @@
 #
 # Natural Language Toolkit: Sentiment Analyzer
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Pierpaolo Pantone <24alsecondo@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -10,7 +10,6 @@
 """
 Utility methods for Sentiment Analysis.
 """
-from __future__ import division
 
 import codecs
 import csv
@@ -21,17 +20,15 @@ import re
 import sys
 import time
 from copy import deepcopy
-from itertools import tee
 
 import nltk
 from nltk.corpus import CategorizedPlaintextCorpusReader
 from nltk.data import load
 from nltk.tokenize.casual import EMOTICON_RE
-from nltk.twitter.common import outf_writer_compat, extract_fields
 
-#////////////////////////////////////////////////////////////
-#{ Regular expressions
-#////////////////////////////////////////////////////////////
+# ////////////////////////////////////////////////////////////
+# { Regular expressions
+# ////////////////////////////////////////////////////////////
 
 # Regular expression for negation by Christopher Potts
 NEGATION = r"""
@@ -46,30 +43,99 @@ NEGATION = r"""
 
 NEGATION_RE = re.compile(NEGATION, re.VERBOSE)
 
-CLAUSE_PUNCT = r'^[.:;!?]$'
+CLAUSE_PUNCT = r"^[.:;!?]$"
 CLAUSE_PUNCT_RE = re.compile(CLAUSE_PUNCT)
 
 # Happy and sad emoticons
 
-HAPPY = set([
-    ':-)', ':)', ';)', ':o)', ':]', ':3', ':c)', ':>', '=]', '8)', '=)', ':}',
-    ':^)', ':-D', ':D', '8-D', '8D', 'x-D', 'xD', 'X-D', 'XD', '=-D', '=D',
-    '=-3', '=3', ':-))', ":'-)", ":')", ':*', ':^*', '>:P', ':-P', ':P', 'X-P',
-    'x-p', 'xp', 'XP', ':-p', ':p', '=p', ':-b', ':b', '>:)', '>;)', '>:-)',
-    '<3'
-    ])
+HAPPY = set(
+    [
+        ":-)",
+        ":)",
+        ";)",
+        ":o)",
+        ":]",
+        ":3",
+        ":c)",
+        ":>",
+        "=]",
+        "8)",
+        "=)",
+        ":}",
+        ":^)",
+        ":-D",
+        ":D",
+        "8-D",
+        "8D",
+        "x-D",
+        "xD",
+        "X-D",
+        "XD",
+        "=-D",
+        "=D",
+        "=-3",
+        "=3",
+        ":-))",
+        ":'-)",
+        ":')",
+        ":*",
+        ":^*",
+        ">:P",
+        ":-P",
+        ":P",
+        "X-P",
+        "x-p",
+        "xp",
+        "XP",
+        ":-p",
+        ":p",
+        "=p",
+        ":-b",
+        ":b",
+        ">:)",
+        ">;)",
+        ">:-)",
+        "<3",
+    ]
+)
 
-SAD = set([
-    ':L', ':-/', '>:/', ':S', '>:[', ':@', ':-(', ':[', ':-||', '=L', ':<',
-    ':-[', ':-<', '=\\', '=/', '>:(', ':(', '>.<', ":'-(", ":'(", ':\\', ':-c',
-    ':c', ':{', '>:\\', ';('
-    ])
+SAD = set(
+    [
+        ":L",
+        ":-/",
+        ">:/",
+        ":S",
+        ">:[",
+        ":@",
+        ":-(",
+        ":[",
+        ":-||",
+        "=L",
+        ":<",
+        ":-[",
+        ":-<",
+        "=\\",
+        "=/",
+        ">:(",
+        ":(",
+        ">.<",
+        ":'-(",
+        ":'(",
+        ":\\",
+        ":-c",
+        ":c",
+        ":{",
+        ">:\\",
+        ";(",
+    ]
+)
 
 
 def timer(method):
     """
     A timer decorator to measure execution performance of methods.
     """
+
     def timed(*args, **kw):
         start = time.time()
         result = method(*args, **kw)
@@ -80,28 +146,28 @@ def timer(method):
         # in Python 2.x round() will return a float, so we convert it to int
         secs = int(round(tot_time % 60))
         if hours == 0 and mins == 0 and secs < 10:
-            print('[TIMER] {0}(): {:.3f} seconds'.format(method.__name__, tot_time))
+            print("[TIMER] {0}(): {:.3f} seconds".format(method.__name__, tot_time))
         else:
-            print('[TIMER] {0}(): {1}h {2}m {3}s'.format(method.__name__, hours, mins, secs))
+            print(
+                "[TIMER] {0}(): {1}h {2}m {3}s".format(
+                    method.__name__, hours, mins, secs
+                )
+            )
         return result
+
     return timed
 
 
-def pairwise(iterable):
-    """s -> (s0,s1), (s1,s2), (s2, s3), ..."""
-    a, b = tee(iterable)
-    next(b, None)
-    return zip(a, b)
-
-#////////////////////////////////////////////////////////////
-#{ Feature extractor functions
-#////////////////////////////////////////////////////////////
+# ////////////////////////////////////////////////////////////
+# { Feature extractor functions
+# ////////////////////////////////////////////////////////////
 """
 Feature extractor functions are declared outside the SentimentAnalyzer class.
 Users should have the possibility to create their own feature extractors
 without modifying SentimentAnalyzer.
 """
 
+
 def extract_unigram_feats(document, unigrams, handle_negation=False):
     """
     Populate a dictionary of unigram features, reflecting the presence/absence in
@@ -123,9 +189,10 @@ def extract_unigram_feats(document, unigrams, handle_negation=False):
     if handle_negation:
         document = mark_negation(document)
     for word in unigrams:
-        features['contains({0})'.format(word)] = word in set(document)
+        features["contains({0})".format(word)] = word in set(document)
     return features
 
+
 def extract_bigram_feats(document, bigrams):
     """
     Populate a dictionary of bigram features, reflecting the presence/absence in
@@ -145,12 +212,16 @@ def extract_bigram_feats(document, bigrams):
     """
     features = {}
     for bigr in bigrams:
-        features['contains({0} - {1})'.format(bigr[0], bigr[1])] = bigr in nltk.bigrams(document)
+        features["contains({0} - {1})".format(bigr[0], bigr[1])] = bigr in nltk.bigrams(
+            document
+        )
     return features
 
-#////////////////////////////////////////////////////////////
-#{ Helper Functions
-#////////////////////////////////////////////////////////////
+
+# ////////////////////////////////////////////////////////////
+# { Helper Functions
+# ////////////////////////////////////////////////////////////
+
 
 def mark_negation(document, double_neg_flip=False, shallow=False):
     """
@@ -184,43 +255,36 @@ def mark_negation(document, double_neg_flip=False, shallow=False):
                 neg_scope = not neg_scope
                 continue
             else:
-                doc[i] += '_NEG'
+                doc[i] += "_NEG"
         elif neg_scope and CLAUSE_PUNCT_RE.search(word):
             neg_scope = not neg_scope
         elif neg_scope and not CLAUSE_PUNCT_RE.search(word):
-            doc[i] += '_NEG'
+            doc[i] += "_NEG"
 
     return document
 
+
 def output_markdown(filename, **kwargs):
     """
     Write the output of an analysis to a file.
     """
-    with codecs.open(filename, 'at') as outfile:
-        text = '\n*** \n\n'
-        text += '{0} \n\n'.format(time.strftime("%d/%m/%Y, %H:%M"))
+    with codecs.open(filename, "at") as outfile:
+        text = "\n*** \n\n"
+        text += "{0} \n\n".format(time.strftime("%d/%m/%Y, %H:%M"))
         for k in sorted(kwargs):
             if isinstance(kwargs[k], dict):
                 dictionary = kwargs[k]
-                text += '  - **{0}:**\n'.format(k)
+                text += "  - **{0}:**\n".format(k)
                 for entry in sorted(dictionary):
-                    text += '    - {0}: {1} \n'.format(entry, dictionary[entry])
+                    text += "    - {0}: {1} \n".format(entry, dictionary[entry])
             elif isinstance(kwargs[k], list):
-                text += '  - **{0}:**\n'.format(k)
+                text += "  - **{0}:**\n".format(k)
                 for entry in kwargs[k]:
-                    text += '    - {0}\n'.format(entry)
+                    text += "    - {0}\n".format(entry)
             else:
-                text += '  - **{0}:** {1} \n'.format(k, kwargs[k])
+                text += "  - **{0}:** {1} \n".format(k, kwargs[k])
         outfile.write(text)
 
-def save_file(content, filename):
-    """
-    Store `content` in `filename`. Can be used to store a SentimentAnalyzer.
-    """
-    print("Saving", filename)
-    with codecs.open(filename, 'wb') as storage_file:
-        # The protocol=2 parameter is for python2 compatibility
-        pickle.dump(content, storage_file, protocol=2)
 
 def split_train_test(all_instances, n=None):
     """
@@ -236,40 +300,55 @@ def split_train_test(all_instances, n=None):
     random.shuffle(all_instances)
     if not n or n > len(all_instances):
         n = len(all_instances)
-    train_set = all_instances[:int(.8*n)]
-    test_set = all_instances[int(.8*n):n]
+    train_set = all_instances[: int(0.8 * n)]
+    test_set = all_instances[int(0.8 * n) : n]
 
     return train_set, test_set
 
+
 def _show_plot(x_values, y_values, x_labels=None, y_labels=None):
     try:
         import matplotlib.pyplot as plt
     except ImportError:
-        raise ImportError('The plot function requires matplotlib to be installed.'
-                         'See http://matplotlib.org/')
+        raise ImportError(
+            "The plot function requires matplotlib to be installed."
+            "See http://matplotlib.org/"
+        )
 
-    plt.locator_params(axis='y', nbins=3)
+    plt.locator_params(axis="y", nbins=3)
     axes = plt.axes()
     axes.yaxis.grid()
-    plt.plot(x_values, y_values, 'ro', color='red')
+    plt.plot(x_values, y_values, "ro", color="red")
     plt.ylim(ymin=-1.2, ymax=1.2)
     plt.tight_layout(pad=5)
     if x_labels:
-        plt.xticks(x_values, x_labels, rotation='vertical')
+        plt.xticks(x_values, x_labels, rotation="vertical")
     if y_labels:
-        plt.yticks([-1, 0, 1], y_labels, rotation='horizontal')
+        plt.yticks([-1, 0, 1], y_labels, rotation="horizontal")
     # Pad margins so that markers are not clipped by the axes
     plt.margins(0.2)
     plt.show()
 
-#////////////////////////////////////////////////////////////
-#{ Parsing and conversion functions
-#////////////////////////////////////////////////////////////
 
-def json2csv_preprocess(json_file, outfile, fields, encoding='utf8', errors='replace',
-            gzip_compress=False, skip_retweets=True, skip_tongue_tweets=True,
-            skip_ambiguous_tweets=True, strip_off_emoticons=True, remove_duplicates=True,
-            limit=None):
+# ////////////////////////////////////////////////////////////
+# { Parsing and conversion functions
+# ////////////////////////////////////////////////////////////
+
+
+def json2csv_preprocess(
+    json_file,
+    outfile,
+    fields,
+    encoding="utf8",
+    errors="replace",
+    gzip_compress=False,
+    skip_retweets=True,
+    skip_tongue_tweets=True,
+    skip_ambiguous_tweets=True,
+    strip_off_emoticons=True,
+    remove_duplicates=True,
+    limit=None,
+):
     """
     Convert json file to csv file, preprocessing each row to obtain a suitable
     dataset for tweets Semantic Analysis.
@@ -294,7 +373,7 @@ def json2csv_preprocess(json_file, outfile, fields, encoding='utf8', errors='rep
         subsets of the original tweets json data.
     """
     with codecs.open(json_file, encoding=encoding) as fp:
-        (writer, outf) = outf_writer_compat(outfile, encoding, errors, gzip_compress)
+        (writer, outf) = _outf_writer(outfile, encoding, errors, gzip_compress)
         # write the list of fields as header
         writer.writerow(fields)
 
@@ -305,14 +384,14 @@ def json2csv_preprocess(json_file, outfile, fields, encoding='utf8', errors='rep
             tweet = json.loads(line)
             row = extract_fields(tweet, fields)
             try:
-                text = row[fields.index('text')]
+                text = row[fields.index("text")]
                 # Remove retweets
                 if skip_retweets == True:
-                    if re.search(r'\bRT\b', text):
+                    if re.search(r"\bRT\b", text):
                         continue
                 # Remove tweets containing ":P" and ":-P" emoticons
                 if skip_tongue_tweets == True:
-                    if re.search(r'\:\-?P\b', text):
+                    if re.search(r"\:\-?P\b", text):
                         continue
                 # Remove tweets containing both happy and sad emoticons
                 if skip_ambiguous_tweets == True:
@@ -322,13 +401,15 @@ def json2csv_preprocess(json_file, outfile, fields, encoding='utf8', errors='rep
                             continue
                 # Strip off emoticons from all tweets
                 if strip_off_emoticons == True:
-                    row[fields.index('text')] = re.sub(r'(?!\n)\s+', ' ', EMOTICON_RE.sub('', text))
+                    row[fields.index("text")] = re.sub(
+                        r"(?!\n)\s+", " ", EMOTICON_RE.sub("", text)
+                    )
                 # Remove duplicate tweets
                 if remove_duplicates == True:
-                    if row[fields.index('text')] in tweets_cache:
+                    if row[fields.index("text")] in tweets_cache:
                         continue
                     else:
-                        tweets_cache.append(row[fields.index('text')])
+                        tweets_cache.append(row[fields.index("text")])
             except ValueError:
                 pass
             writer.writerow(row)
@@ -337,8 +418,10 @@ def json2csv_preprocess(json_file, outfile, fields, encoding='utf8', errors='rep
                 break
         outf.close()
 
-def parse_tweets_set(filename, label, word_tokenizer=None, sent_tokenizer=None,
-                     skip_header=True):
+
+def parse_tweets_set(
+    filename, label, word_tokenizer=None, sent_tokenizer=None, skip_header=True
+):
     """
     Parse csv file containing tweets and output data a list of (text, label) tuples.
 
@@ -356,51 +439,36 @@ def parse_tweets_set(filename, label, word_tokenizer=None, sent_tokenizer=None,
     """
     tweets = []
     if not sent_tokenizer:
-        sent_tokenizer = load('tokenizers/punkt/english.pickle')
+        sent_tokenizer = load("tokenizers/punkt/english.pickle")
+
+    with codecs.open(filename, "rt") as csvfile:
+        reader = csv.reader(csvfile)
+        if skip_header == True:
+            next(reader, None)  # skip the header
+        i = 0
+        for tweet_id, text in reader:
+            # text = text[1]
+            i += 1
+            sys.stdout.write("Loaded {0} tweets\r".format(i))
+            # Apply sentence and word tokenizer to text
+            if word_tokenizer:
+                tweet = [
+                    w
+                    for sent in sent_tokenizer.tokenize(text)
+                    for w in word_tokenizer.tokenize(sent)
+                ]
+            else:
+                tweet = text
+            tweets.append((tweet, label))
 
-    # If we use Python3.x we can proceed using the 'rt' flag
-    if sys.version_info[0] == 3:
-        with codecs.open(filename, 'rt') as csvfile:
-            reader = csv.reader(csvfile)
-            if skip_header == True:
-                next(reader, None) # skip the header
-            i = 0
-            for tweet_id, text in reader:
-                # text = text[1]
-                i += 1
-                sys.stdout.write('Loaded {0} tweets\r'.format(i))
-                # Apply sentence and word tokenizer to text
-                if word_tokenizer:
-                    tweet = [w for sent in sent_tokenizer.tokenize(text)
-                                       for w in word_tokenizer.tokenize(sent)]
-                else:
-                    tweet = text
-                tweets.append((tweet, label))
-    # If we use Python2.x we need to handle encoding problems
-    elif sys.version_info[0] < 3:
-        with codecs.open(filename) as csvfile:
-            reader = csv.reader(csvfile)
-            if skip_header == True:
-                next(reader, None) # skip the header
-            i = 0
-            for row in reader:
-                unicode_row = [x.decode('utf8') for x in row]
-                text = unicode_row[1]
-                i += 1
-                sys.stdout.write('Loaded {0} tweets\r'.format(i))
-                # Apply sentence and word tokenizer to text
-                if word_tokenizer:
-                    tweet = [w.encode('utf8') for sent in sent_tokenizer.tokenize(text)
-                                       for w in word_tokenizer.tokenize(sent)]
-                else:
-                    tweet = text
-                tweets.append((tweet, label))
     print("Loaded {0} tweets".format(i))
     return tweets
 
-#////////////////////////////////////////////////////////////
-#{ Demos
-#////////////////////////////////////////////////////////////
+
+# ////////////////////////////////////////////////////////////
+# { Demos
+# ////////////////////////////////////////////////////////////
+
 
 def demo_tweets(trainer, n_instances=None, output=None):
     """
@@ -426,27 +494,27 @@ def demo_tweets(trainer, n_instances=None, output=None):
     # tokenizer = TweetTokenizer(reduce_len=True, strip_handles=True)
 
     if n_instances is not None:
-        n_instances = int(n_instances/2)
+        n_instances = int(n_instances / 2)
 
-    fields = ['id', 'text']
+    fields = ["id", "text"]
     positive_json = twitter_samples.abspath("positive_tweets.json")
-    positive_csv = 'positive_tweets.csv'
+    positive_csv = "positive_tweets.csv"
     json2csv_preprocess(positive_json, positive_csv, fields, limit=n_instances)
 
     negative_json = twitter_samples.abspath("negative_tweets.json")
-    negative_csv = 'negative_tweets.csv'
+    negative_csv = "negative_tweets.csv"
     json2csv_preprocess(negative_json, negative_csv, fields, limit=n_instances)
 
-    neg_docs = parse_tweets_set(negative_csv, label='neg', word_tokenizer=tokenizer)
-    pos_docs = parse_tweets_set(positive_csv, label='pos', word_tokenizer=tokenizer)
+    neg_docs = parse_tweets_set(negative_csv, label="neg", word_tokenizer=tokenizer)
+    pos_docs = parse_tweets_set(positive_csv, label="pos", word_tokenizer=tokenizer)
 
     # We separately split subjective and objective instances to keep a balanced
     # uniform class distribution in both train and test sets.
     train_pos_docs, test_pos_docs = split_train_test(pos_docs)
     train_neg_docs, test_neg_docs = split_train_test(neg_docs)
 
-    training_tweets = train_pos_docs+train_neg_docs
-    testing_tweets = test_pos_docs+test_neg_docs
+    training_tweets = train_pos_docs + train_neg_docs
+    testing_tweets = test_pos_docs + test_neg_docs
 
     sentim_analyzer = SentimentAnalyzer()
     # stopwords = stopwords.words('english')
@@ -458,9 +526,12 @@ def demo_tweets(trainer, n_instances=None, output=None):
     sentim_analyzer.add_feat_extractor(extract_unigram_feats, unigrams=unigram_feats)
 
     # Add bigram collocation features
-    bigram_collocs_feats = sentim_analyzer.bigram_collocation_feats([tweet[0] for tweet in training_tweets],
-        top_n=100, min_freq=12)
-    sentim_analyzer.add_feat_extractor(extract_bigram_feats, bigrams=bigram_collocs_feats)
+    bigram_collocs_feats = sentim_analyzer.bigram_collocation_feats(
+        [tweet[0] for tweet in training_tweets], top_n=100, min_freq=12
+    )
+    sentim_analyzer.add_feat_extractor(
+        extract_bigram_feats, bigrams=bigram_collocs_feats
+    )
 
     training_set = sentim_analyzer.apply_features(training_tweets)
     test_set = sentim_analyzer.apply_features(testing_tweets)
@@ -470,14 +541,23 @@ def demo_tweets(trainer, n_instances=None, output=None):
     try:
         classifier.show_most_informative_features()
     except AttributeError:
-        print('Your classifier does not provide a show_most_informative_features() method.')
+        print(
+            "Your classifier does not provide a show_most_informative_features() method."
+        )
     results = sentim_analyzer.evaluate(test_set)
 
     if output:
         extr = [f.__name__ for f in sentim_analyzer.feat_extractors]
-        output_markdown(output, Dataset='labeled_tweets', Classifier=type(classifier).__name__,
-                        Tokenizer=tokenizer.__class__.__name__, Feats=extr,
-                        Results=results, Instances=n_instances)
+        output_markdown(
+            output,
+            Dataset="labeled_tweets",
+            Classifier=type(classifier).__name__,
+            Tokenizer=tokenizer.__class__.__name__,
+            Feats=extr,
+            Results=results,
+            Instances=n_instances,
+        )
+
 
 def demo_movie_reviews(trainer, n_instances=None, output=None):
     """
@@ -497,17 +577,23 @@ def demo_movie_reviews(trainer, n_instances=None, output=None):
     from nltk.sentiment import SentimentAnalyzer
 
     if n_instances is not None:
-        n_instances = int(n_instances/2)
+        n_instances = int(n_instances / 2)
 
-    pos_docs = [(list(movie_reviews.words(pos_id)), 'pos') for pos_id in movie_reviews.fileids('pos')[:n_instances]]
-    neg_docs = [(list(movie_reviews.words(neg_id)), 'neg') for neg_id in movie_reviews.fileids('neg')[:n_instances]]
+    pos_docs = [
+        (list(movie_reviews.words(pos_id)), "pos")
+        for pos_id in movie_reviews.fileids("pos")[:n_instances]
+    ]
+    neg_docs = [
+        (list(movie_reviews.words(neg_id)), "neg")
+        for neg_id in movie_reviews.fileids("neg")[:n_instances]
+    ]
     # We separately split positive and negative instances to keep a balanced
     # uniform class distribution in both train and test sets.
     train_pos_docs, test_pos_docs = split_train_test(pos_docs)
     train_neg_docs, test_neg_docs = split_train_test(neg_docs)
 
-    training_docs = train_pos_docs+train_neg_docs
-    testing_docs = test_pos_docs+test_neg_docs
+    training_docs = train_pos_docs + train_neg_docs
+    testing_docs = test_pos_docs + test_neg_docs
 
     sentim_analyzer = SentimentAnalyzer()
     all_words = sentim_analyzer.all_words(training_docs)
@@ -523,14 +609,23 @@ def demo_movie_reviews(trainer, n_instances=None, output=None):
     try:
         classifier.show_most_informative_features()
     except AttributeError:
-        print('Your classifier does not provide a show_most_informative_features() method.')
+        print(
+            "Your classifier does not provide a show_most_informative_features() method."
+        )
     results = sentim_analyzer.evaluate(test_set)
 
     if output:
         extr = [f.__name__ for f in sentim_analyzer.feat_extractors]
-        output_markdown(output, Dataset='Movie_reviews', Classifier=type(classifier).__name__,
-                        Tokenizer='WordPunctTokenizer', Feats=extr, Results=results,
-                        Instances=n_instances)
+        output_markdown(
+            output,
+            Dataset="Movie_reviews",
+            Classifier=type(classifier).__name__,
+            Tokenizer="WordPunctTokenizer",
+            Feats=extr,
+            Results=results,
+            Instances=n_instances,
+        )
+
 
 def demo_subjectivity(trainer, save_analyzer=False, n_instances=None, output=None):
     """
@@ -550,21 +645,27 @@ def demo_subjectivity(trainer, save_analyzer=False, n_instances=None, output=Non
     from nltk.corpus import subjectivity
 
     if n_instances is not None:
-        n_instances = int(n_instances/2)
+        n_instances = int(n_instances / 2)
 
-    subj_docs = [(sent, 'subj') for sent in subjectivity.sents(categories='subj')[:n_instances]]
-    obj_docs = [(sent, 'obj') for sent in subjectivity.sents(categories='obj')[:n_instances]]
+    subj_docs = [
+        (sent, "subj") for sent in subjectivity.sents(categories="subj")[:n_instances]
+    ]
+    obj_docs = [
+        (sent, "obj") for sent in subjectivity.sents(categories="obj")[:n_instances]
+    ]
 
     # We separately split subjective and objective instances to keep a balanced
     # uniform class distribution in both train and test sets.
     train_subj_docs, test_subj_docs = split_train_test(subj_docs)
     train_obj_docs, test_obj_docs = split_train_test(obj_docs)
 
-    training_docs = train_subj_docs+train_obj_docs
-    testing_docs = test_subj_docs+test_obj_docs
+    training_docs = train_subj_docs + train_obj_docs
+    testing_docs = test_subj_docs + test_obj_docs
 
     sentim_analyzer = SentimentAnalyzer()
-    all_words_neg = sentim_analyzer.all_words([mark_negation(doc) for doc in training_docs])
+    all_words_neg = sentim_analyzer.all_words(
+        [mark_negation(doc) for doc in training_docs]
+    )
 
     # Add simple unigram word features handling negation
     unigram_feats = sentim_analyzer.unigram_word_feats(all_words_neg, min_freq=4)
@@ -578,20 +679,29 @@ def demo_subjectivity(trainer, save_analyzer=False, n_instances=None, output=Non
     try:
         classifier.show_most_informative_features()
     except AttributeError:
-        print('Your classifier does not provide a show_most_informative_features() method.')
+        print(
+            "Your classifier does not provide a show_most_informative_features() method."
+        )
     results = sentim_analyzer.evaluate(test_set)
 
     if save_analyzer == True:
-        save_file(sentim_analyzer, 'sa_subjectivity.pickle')
+        save_file(sentim_analyzer, "sa_subjectivity.pickle")
 
     if output:
         extr = [f.__name__ for f in sentim_analyzer.feat_extractors]
-        output_markdown(output, Dataset='subjectivity', Classifier=type(classifier).__name__,
-                        Tokenizer='WhitespaceTokenizer', Feats=extr,
-                        Instances=n_instances, Results=results)
+        output_markdown(
+            output,
+            Dataset="subjectivity",
+            Classifier=type(classifier).__name__,
+            Tokenizer="WhitespaceTokenizer",
+            Feats=extr,
+            Instances=n_instances,
+            Results=results,
+        )
 
     return sentim_analyzer
 
+
 def demo_sent_subjectivity(text):
     """
     Classify a single sentence as subjective or objective using a stored
@@ -601,18 +711,20 @@ def demo_sent_subjectivity(text):
     """
     from nltk.classify import NaiveBayesClassifier
     from nltk.tokenize import regexp
+
     word_tokenizer = regexp.WhitespaceTokenizer()
     try:
-        sentim_analyzer = load('sa_subjectivity.pickle')
+        sentim_analyzer = load("sa_subjectivity.pickle")
     except LookupError:
-        print('Cannot find the sentiment analyzer you want to load.')
-        print('Training a new one using NaiveBayesClassifier.')
+        print("Cannot find the sentiment analyzer you want to load.")
+        print("Training a new one using NaiveBayesClassifier.")
         sentim_analyzer = demo_subjectivity(NaiveBayesClassifier.train, True)
 
     # Tokenize and convert to lower case
     tokenized_text = [word.lower() for word in word_tokenizer.tokenize(text)]
     print(sentim_analyzer.classify(tokenized_text))
 
+
 def demo_liu_hu_lexicon(sentence, plot=False):
     """
     Basic example of sentiment classification using Liu and Hu opinion lexicon.
@@ -631,28 +743,31 @@ def demo_liu_hu_lexicon(sentence, plot=False):
     neg_words = 0
     tokenized_sent = [word.lower() for word in tokenizer.tokenize(sentence)]
 
-    x = list(range(len(tokenized_sent))) # x axis for the plot
+    x = list(range(len(tokenized_sent)))  # x axis for the plot
     y = []
 
     for word in tokenized_sent:
         if word in opinion_lexicon.positive():
             pos_words += 1
-            y.append(1) # positive
+            y.append(1)  # positive
         elif word in opinion_lexicon.negative():
             neg_words += 1
-            y.append(-1) # negative
+            y.append(-1)  # negative
         else:
-            y.append(0) # neutral
+            y.append(0)  # neutral
 
     if pos_words > neg_words:
-        print('Positive')
+        print("Positive")
     elif pos_words < neg_words:
-        print('Negative')
+        print("Negative")
     elif pos_words == neg_words:
-        print('Neutral')
+        print("Neutral")
 
     if plot == True:
-        _show_plot(x, y, x_labels=tokenized_sent, y_labels=['Negative', 'Neutral', 'Positive'])
+        _show_plot(
+            x, y, x_labels=tokenized_sent, y_labels=["Negative", "Neutral", "Positive"]
+        )
+
 
 def demo_vader_instance(text):
     """
@@ -661,9 +776,11 @@ def demo_vader_instance(text):
     :param text: a text whose polarity has to be evaluated.
     """
     from nltk.sentiment import SentimentIntensityAnalyzer
+
     vader_analyzer = SentimentIntensityAnalyzer()
     print(vader_analyzer.polarity_scores(text))
 
+
 def demo_vader_tweets(n_instances=None, output=None):
     """
     Classify 10000 positive and negative tweets using Vader approach.
@@ -674,33 +791,47 @@ def demo_vader_tweets(n_instances=None, output=None):
     from collections import defaultdict
     from nltk.corpus import twitter_samples
     from nltk.sentiment import SentimentIntensityAnalyzer
-    from nltk.metrics import (accuracy as eval_accuracy, precision as eval_precision,
-        recall as eval_recall, f_measure as eval_f_measure)
+    from nltk.metrics import (
+        accuracy as eval_accuracy,
+        precision as eval_precision,
+        recall as eval_recall,
+        f_measure as eval_f_measure,
+    )
 
     if n_instances is not None:
-        n_instances = int(n_instances/2)
+        n_instances = int(n_instances / 2)
 
-    fields = ['id', 'text']
+    fields = ["id", "text"]
     positive_json = twitter_samples.abspath("positive_tweets.json")
-    positive_csv = 'positive_tweets.csv'
-    json2csv_preprocess(positive_json, positive_csv, fields, strip_off_emoticons=False,
-                        limit=n_instances)
+    positive_csv = "positive_tweets.csv"
+    json2csv_preprocess(
+        positive_json,
+        positive_csv,
+        fields,
+        strip_off_emoticons=False,
+        limit=n_instances,
+    )
 
     negative_json = twitter_samples.abspath("negative_tweets.json")
-    negative_csv = 'negative_tweets.csv'
-    json2csv_preprocess(negative_json, negative_csv, fields, strip_off_emoticons=False,
-                        limit=n_instances)
+    negative_csv = "negative_tweets.csv"
+    json2csv_preprocess(
+        negative_json,
+        negative_csv,
+        fields,
+        strip_off_emoticons=False,
+        limit=n_instances,
+    )
 
-    pos_docs = parse_tweets_set(positive_csv, label='pos')
-    neg_docs = parse_tweets_set(negative_csv, label='neg')
+    pos_docs = parse_tweets_set(positive_csv, label="pos")
+    neg_docs = parse_tweets_set(negative_csv, label="neg")
 
     # We separately split subjective and objective instances to keep a balanced
     # uniform class distribution in both train and test sets.
     train_pos_docs, test_pos_docs = split_train_test(pos_docs)
     train_neg_docs, test_neg_docs = split_train_test(neg_docs)
 
-    training_tweets = train_pos_docs+train_neg_docs
-    testing_tweets = test_pos_docs+test_neg_docs
+    training_tweets = train_pos_docs + train_neg_docs
+    testing_tweets = test_pos_docs + test_neg_docs
 
     vader_analyzer = SentimentIntensityAnalyzer()
 
@@ -714,40 +845,43 @@ def demo_vader_tweets(n_instances=None, output=None):
         labels.add(label)
         gold_results[label].add(i)
         acc_gold_results.append(label)
-        score = vader_analyzer.polarity_scores(text)['compound']
+        score = vader_analyzer.polarity_scores(text)["compound"]
         if score > 0:
-            observed = 'pos'
+            observed = "pos"
         else:
-            observed = 'neg'
+            observed = "neg"
         num += 1
         acc_test_results.append(observed)
         test_results[observed].add(i)
     metrics_results = {}
     for label in labels:
-        accuracy_score = eval_accuracy(acc_gold_results,
-            acc_test_results)
-        metrics_results['Accuracy'] = accuracy_score
-        precision_score = eval_precision(gold_results[label],
-            test_results[label])
-        metrics_results['Precision [{0}]'.format(label)] = precision_score
-        recall_score = eval_recall(gold_results[label],
-            test_results[label])
-        metrics_results['Recall [{0}]'.format(label)] = recall_score
-        f_measure_score = eval_f_measure(gold_results[label],
-            test_results[label])
-        metrics_results['F-measure [{0}]'.format(label)] = f_measure_score
+        accuracy_score = eval_accuracy(acc_gold_results, acc_test_results)
+        metrics_results["Accuracy"] = accuracy_score
+        precision_score = eval_precision(gold_results[label], test_results[label])
+        metrics_results["Precision [{0}]".format(label)] = precision_score
+        recall_score = eval_recall(gold_results[label], test_results[label])
+        metrics_results["Recall [{0}]".format(label)] = recall_score
+        f_measure_score = eval_f_measure(gold_results[label], test_results[label])
+        metrics_results["F-measure [{0}]".format(label)] = f_measure_score
 
     for result in sorted(metrics_results):
-            print('{0}: {1}'.format(result, metrics_results[result]))
+        print("{0}: {1}".format(result, metrics_results[result]))
 
     if output:
-        output_markdown(output, Approach='Vader', Dataset='labeled_tweets',
-            Instances=n_instances, Results=metrics_results)
+        output_markdown(
+            output,
+            Approach="Vader",
+            Dataset="labeled_tweets",
+            Instances=n_instances,
+            Results=metrics_results,
+        )
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     from nltk.classify import NaiveBayesClassifier, MaxentClassifier
     from nltk.classify.scikitlearn import SklearnClassifier
     from sklearn.svm import LinearSVC
+    from nltk.twitter.common import _outf_writer, extract_fields
 
     naive_bayes = NaiveBayesClassifier.train
     svm = SklearnClassifier(LinearSVC()).train
