@@ -1,18 +1,23 @@
 # Natural Language Toolkit: Stemmer Interface
 #
-# Copyright (C) 2001-2017 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Trevor Cohn <tacohn@cs.mu.oz.au>
 #         Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-class StemmerI(object):
+from abc import ABCMeta, abstractmethod
+
+
+class StemmerI(metaclass=ABCMeta):
     """
     A processing interface for removing morphological affixes from
     words.  This process is known as stemming.
 
     """
+
+    @abstractmethod
     def stem(self, token):
         """
         Strip affixes from the token and return the stem.
@@ -20,6 +25,3 @@ class StemmerI(object):
         :param token: The token that should be stemmed.
         :type token: str
         """
-        raise NotImplementedError()
-
-
