@@ -1,7 +1,7 @@
 # encoding: utf-8
 # Natural Language Toolkit: Senna POS Tagger
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Rami Al-Rfou' <ralrfou@cs.stonybrook.edu>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -39,13 +39,13 @@ Note: Unit tests for this module can be found in test/unit/test_senna.py
     ('NY', 'B-LOC'), (',', 'O'), ('USA', 'B-LOC'), ('.', 'O')]
 """
 
-from nltk.compat import python_2_unicode_compatible
 from nltk.classify import Senna
 
-@python_2_unicode_compatible
+
+
 class SennaTagger(Senna):
-    def __init__(self, path, encoding='utf-8'):
-        super(SennaTagger, self).__init__(path, ['pos'], encoding)
+    def __init__(self, path, encoding="utf-8"):
+        super(SennaTagger, self).__init__(path, ["pos"], encoding)
 
     def tag_sents(self, sentences):
         """
@@ -56,13 +56,14 @@ class SennaTagger(Senna):
         for i in range(len(tagged_sents)):
             for j in range(len(tagged_sents[i])):
                 annotations = tagged_sents[i][j]
-                tagged_sents[i][j] = (annotations['word'], annotations['pos'])
+                tagged_sents[i][j] = (annotations["word"], annotations["pos"])
         return tagged_sents
 
-@python_2_unicode_compatible
+
+
 class SennaChunkTagger(Senna):
-    def __init__(self, path, encoding='utf-8'):
-        super(SennaChunkTagger, self).__init__(path, ['chk'], encoding)
+    def __init__(self, path, encoding="utf-8"):
+        super(SennaChunkTagger, self).__init__(path, ["chk"], encoding)
 
     def tag_sents(self, sentences):
         """
@@ -73,7 +74,7 @@ class SennaChunkTagger(Senna):
         for i in range(len(tagged_sents)):
             for j in range(len(tagged_sents[i])):
                 annotations = tagged_sents[i][j]
-                tagged_sents[i][j] = (annotations['word'], annotations['chk'])
+                tagged_sents[i][j] = (annotations["word"], annotations["chk"])
         return tagged_sents
 
     def bio_to_chunks(self, tagged_sent, chunk_type):
@@ -104,24 +105,24 @@ class SennaChunkTagger(Senna):
         current_chunk_position = []
         for idx, word_pos in enumerate(tagged_sent):
             word, pos = word_pos
-            if '-'+chunk_type in pos: # Append the word to the current_chunk.
+            if "-" + chunk_type in pos:  # Append the word to the current_chunk.
                 current_chunk.append((word))
                 current_chunk_position.append((idx))
             else:
-                if current_chunk: # Flush the full chunk when out of an NP.
-                    _chunk_str = ' '.join(current_chunk)
-                    _chunk_pos_str = '-'.join(map(str, current_chunk_position))
+                if current_chunk:  # Flush the full chunk when out of an NP.
+                    _chunk_str = " ".join(current_chunk)
+                    _chunk_pos_str = "-".join(map(str, current_chunk_position))
                     yield _chunk_str, _chunk_pos_str
                     current_chunk = []
                     current_chunk_position = []
-        if current_chunk: # Flush the last chunk.
-            yield ' '.join(current_chunk), '-'.join(map(str, current_chunk_position))
+        if current_chunk:  # Flush the last chunk.
+            yield " ".join(current_chunk), "-".join(map(str, current_chunk_position))
+
 
 
-@python_2_unicode_compatible
 class SennaNERTagger(Senna):
-    def __init__(self, path, encoding='utf-8'):
-        super(SennaNERTagger, self).__init__(path, ['ner'], encoding)
+    def __init__(self, path, encoding="utf-8"):
+        super(SennaNERTagger, self).__init__(path, ["ner"], encoding)
 
     def tag_sents(self, sentences):
         """
@@ -132,16 +133,15 @@ class SennaNERTagger(Senna):
         for i in range(len(tagged_sents)):
             for j in range(len(tagged_sents[i])):
                 annotations = tagged_sents[i][j]
-                tagged_sents[i][j] = (annotations['word'], annotations['ner'])
+                tagged_sents[i][j] = (annotations["word"], annotations["ner"])
         return tagged_sents
 
 
-
 # skip doctests if Senna is not installed
 def setup_module(module):
     from nose import SkipTest
+
     try:
-        tagger = Senna('/usr/share/senna-v3.0', ['pos', 'chk', 'ner'])
+        tagger = Senna("/usr/share/senna-v3.0", ["pos", "chk", "ner"])
     except OSError:
         raise SkipTest("Senna executable not found")
-
